import { PropsWithChildren } from "react";
import classNames from "classnames";
import styles from "./index.module.css";

interface ArrowTagProps {
  direction?: "right" | "left";
  color?: string;
  style?: React.CSSProperties;
  height?: number;
  width?: number;
  customTriangleStyleStyle?: React.CSSProperties;
  text?: string;
  //** 语义化className */
  customClassNames?: {
    body?: string;
    triangle?: string;
  };
}

const ArrowTag: React.FC<PropsWithChildren<ArrowTagProps>> = (props) => {
  const {
    direction = "left",
    children,
    color = "#B9D9FF",
    width,
    customClassNames,
    style,
    customTriangleStyleStyle,
    height = 36,
    text,
  } = props;

  const triangleStyle = {
    borderWidth:
      direction === "left"
        ? `${height / 2}px  ${height / 2.5}px ${height / 2}px 0`
        : `${height / 2}px 0 ${height / 2}px  ${height / 2}px`,
    borderColor:
      direction === "left"
        ? `transparent ${color} transparent transparent`
        : `transparent transparent transparent ${color}`,
  };

  const bodyStyle: React.CSSProperties = {
    backgroundColor: color,
    width,
    height,
    borderRadius:
      direction === "left"
        ? `2px ${height / 6}px ${height / 6}px  2px`
        : `0 0 ${height / 4}px ${height / 4}px`,
    ...style,
  };

  return (
    <div className={styles.container}>
      {direction === "left" && (
        <div
          className={classNames(styles.triangle, customClassNames?.triangle)}
          style={{ ...triangleStyle, ...customTriangleStyleStyle }}
        ></div>
      )}{" "}
      {children ? (
        <div
          style={bodyStyle}
          className={classNames(styles.text, customClassNames?.body)}
        >
          {children}
        </div>
      ) : (
        <div style={bodyStyle} className={styles.text}>
          {text}
        </div>
      )}
      {direction === "right" && (
        <div
          className={classNames(styles.triangle, customClassNames?.triangle)}
          style={{ ...triangleStyle, ...customTriangleStyleStyle }}
        ></div>
      )}
    </div>
  );
};

export default ArrowTag;
