import { CloseOutlined } from "@ant-design/icons";
import Color from "color";
import { PropsWithChildren } from "react";
import styles from "./index.module.css";
import { createPortal } from "react-dom";

interface ModalProps {
  visible: boolean;
  width?: number;
  height?: number;
  contentStyle?: React.CSSProperties;
  wrapStyle?: React.CSSProperties;

  onClose: () => void;
  zIndex?: number;
}

const BasicModal: React.FC<PropsWithChildren<ModalProps>> = (props) => {
  const {
    visible = true,
    children,
    wrapStyle,
    contentStyle,
    onClose,
    width,
    height,
    zIndex,
  } = props;

  if (!visible) {
    return null;
  }
  /** 传送到body，隔绝样式影响 */
  return createPortal(
    <div
      className={styles.modalWrap}
      style={{ zIndex }}
      onClick={(e) => e.stopPropagation()}
    >
      <div className={styles.modalMask} />
      <div className={styles.modalContentWrap} style={wrapStyle}>
        <div
          className={styles.modalContent}
          style={{ width, height, ...contentStyle }}
        >
          <div className={styles.closeBtn} onClick={onClose}>
            <CloseOutlined
              style={{ color: Color("#596576").alpha(0.5).hexa() }}
            />
          </div>
          {children}
        </div>
      </div>
    </div>,
    document.body
  );
};

export default BasicModal;
