import classNames from 'classnames';
import React, { CSSProperties } from 'react';
import styles from './index.module.css';
export interface OptionsDto {
    label: string;
    value: string | number;
    count?: string | number | undefined;
}
interface selectProps {
    options: OptionsDto[];
    defaultId?: string | number;
    style?: CSSProperties;
    onSelect?: (selectId: string | number) => void; //选择项
    isCount?: boolean; //是否计数
    labelWidth?: string;
    activeBg?: string; //激活颜色
    fieldNames?: OptionsDto; //自定义字段
}

const TabSwitch: React.FC<selectProps> = (props) => {
    const {
        options,
        style,
        defaultId = 1,
        isCount,
        labelWidth,
        activeBg = '#2E6CFF',
        onSelect,
        fieldNames = {
            label: 'label',
            value: 'value',
            count: 'count',
        },
    } = props;
    const [selectedId, setSelectedId] = React.useState<
        number | string | undefined
    >(defaultId);
    const handleTab = (row: any) => {
        setSelectedId(row.value);
        onSelect && onSelect(row.value);
    };
    let data = options?.map((it: any) => ({
        label: it[fieldNames.label],
        value: it[fieldNames.value],
        count: it[fieldNames.count as string],
    }));
    return (
        <div
            className={classNames(
                styles.tab_switch,
                data?.length < 2 ? styles.one : '',
            )}
            style={style}
        >
            {data?.map((item) => (
                <span
                    style={{ width: labelWidth, '--color': activeBg } as CSSProperties}
                    className={item.value == selectedId ? styles.active : ''}
                    onClick={() => handleTab(item)}
                    key={item.value}
                >
                    {item.label} {isCount && '· ' + item.count}
                </span>
            ))}
        </div>
    );
};

export default TabSwitch;
