import React, { useEffect, useState } from "react";
import { InboxOutlined } from "@ant-design/icons";
import type { UploadProps } from "antd";
import { message, Upload } from "antd";
import { isEqual } from "lodash";
import { composeImgUrl, downloadFile } from "@/utils";

const { Dragger } = Upload;

interface FileUploadProps {
  onChange: (params?: string) => void;
  value: string;
  placeholder?: string;
  templateUrl?: string;
}

const FileUpload: React.FC<FileUploadProps> = (props) => {
  const { placeholder, value, onChange, templateUrl } = props;
  const [fileList, setFilList] = useState<string[]>([]);
  useEffect(() => {
    if (typeof value === "string") {
      const list = value?.split(",");
      if (list && list.length > 0 && isEqual(fileList, list)) {
        setFilList(list);
      }
    }
  }, [value]);

  const DraggerProps: UploadProps = {
    name: "file",
    multiple: true,
    action: "/apis/oss/upload?bucketName=cgtf",
    maxCount: 1,
    onChange(info) {
      const { status } = info.file;
      if (status === "done") {
        const imgStr = info.fileList.map((item) => {
          return item.response.data;
        }) as string[];
        setFilList(imgStr);
        onChange(imgStr.join(","));
        message.success(`${info.file.name}上传成功.`);
      } else if (status === "error") {
        message.error(`${info.file.name}上传失败.`);
      }
    },
    defaultFileList: fileList.map((v, i) => {
      return {
        uid: (i + 1).toString(),
        name: v,
        status: "done",
        url: v,
      };
    }),
    onDrop(e) {
      console.log("Dropped files", e.dataTransfer.files);
    },
  };
  const onRemove = () => {
    setFilList([]);
    onChange(undefined);
  };

  return (
    <>
      {templateUrl && (
        <div
          style={{ marginBottom: 8 }}
          onClick={() => {
            downloadFile(composeImgUrl(templateUrl), "模板");
          }}
        >
          <a>下载模版</a>
        </div>
      )}
      <Dragger {...DraggerProps} onRemove={onRemove}>
        <p className="ant-upload-drag-icon">
          <InboxOutlined />
        </p>
        <p className="ant-upload-text">
          {placeholder ?? "单击或拖动文件到此区域进行上传"}
        </p>
      </Dragger>
    </>
  );
};

export default FileUpload;
