import { Empty, Flex, Image } from "antd";

import styles from "./attachment.module.css";
import classNames from "classnames";
import { useMemo } from "react";
import { CheckOutlined, FileUnknownOutlined } from "@ant-design/icons";
import { composeImgUrl, downloadFile } from "@/utils";

const Item = ({ label, value }: { label: string; value: string }) => {
  let fileType = "none";

  if (value && value.length > 0) {
    const strList = value?.split(".") ?? [];
    const extra = strList[strList.length - 1];
    // pdf
    if (extra === "pdf") {
      fileType = "pdf";
    }
    //img
    if (extra === "jpg" || extra === "png" || extra === "jpeg") {
      fileType = "img";
    }
    // 其他
    else {
      fileType = "other";
    }
  }

  /** @description 不显示没有文件类型的 */
  if (fileType === "none") {
    return undefined;
  }

  return (
    <div
      className={classNames(
        styles.itemWrapper,
        !value?.length && styles.noItem
      )}
    >
      <Flex align="center" justify="space-between">
        <Flex gap={8} align="center">
          <div className={styles.successIcon}>
            <CheckOutlined />
          </div>
          <div>{label}</div>
        </Flex>
        {fileType === "pdf" && (
          <div
            className={styles.noValueStatus}
            onClick={() => {
              window.open(composeImgUrl(value));
            }}
          >
            <span>pdf</span>
          </div>
        )}
        {fileType === "img" && (
          <Image
            width={40}
            height={40}
            style={{ borderRadius: 4 }}
            src={composeImgUrl(value)}
          ></Image>
        )}

        {fileType === "other" && (
          <div
            className={styles.noValueStatus}
            onClick={() => {
              downloadFile(composeImgUrl(value), label);
            }}
          >
            <FileUnknownOutlined />
          </div>
        )}
      </Flex>
    </div>
  );
};

type AttachmentProps = {
  configSource: any;
  data: any;
};
/** 附件列表 */
const Attachment = (props: AttachmentProps) => {
  const { configSource, data } = props;

  const hasAttachmentConfig = useMemo(() => {
    return (
      configSource?.matterContentList?.filter((v: any) => {
        return (
          v.componentType == "ImgUpload" || v.componentType == "FileUpload"
        );
      }) ?? []
    );
  }, [configSource]);

  const findValue = (key: string) => {
    const reportContents = data?.reportContents ?? [];
    return reportContents.find((v: any) => v.contentId === key)?.content;
  };

  return (
    <div>
      {hasAttachmentConfig.length === 0 && <Empty description="无附件"></Empty>}
      {hasAttachmentConfig.map((item: any) => {
        return (
          <Item
            label={item.label}
            key={item.fieldKey}
            value={findValue(item.fieldKey)}
          ></Item>
        );
      })}
    </div>
  );
};

export default Attachment;
