import { Descriptions, Space } from "antd";
import { useMemo } from "react";

import BaseFormComponent from "@/customForm/entity/base";
import { OnlyProperties } from "@/customForm/interfaces";
import dayjs from "dayjs";

type ContentProps = {
  configSource: any;
  data: any;
};
const Content = (props: ContentProps) => {
  const { configSource, data } = props;

  const config = useMemo(() => {
    const matterContentList = configSource?.matterContentList;

    if (matterContentList) {
      const temp = matterContentList
        .sort((pre: any, cur: any) => pre.sort - cur.sort)
        .map((item: any) => {
          return {
            ...item,
            componentOption: item.otherSet ? JSON.parse(item.otherSet) : {},
            key: item.fieldKey,
          };
        });

      return temp.filter((item: OnlyProperties<BaseFormComponent>) => {
        return (
          item.componentType !== "ImgUpload" &&
          item.componentType !== "FileUpload"
        );
      });
    }
    return [];
  }, [configSource]);

  const renderFormContentByType = (
    component: BaseFormComponent,
    value?: any
  ) => {
    const key = component.key;
    const reportContents = data?.reportContents ?? [];

    const contentValue =
      value ?? reportContents.find((v: any) => v.contentId === key)?.content;

    if (!contentValue) {
      return undefined;
    }
    
    switch (component.componentType) {
      case "TextInput":
        return (
          <div>
            {(component.componentOption.prefix ?? "") +
              contentValue +
              (component.componentOption.suffix ?? "")}
          </div>
        );
      case "DatePicker":
        return (
          <div>
            {dayjs(contentValue).format(
              component.componentOption.picker === "time"
                ? "HH:mm"
                : component.componentOption.picker === "date"
                ? "YYYY-MM-DD"
                : "YYYY-MM"
            )}
          </div>
        );
      case "Branch": {
        const isInfinite = component.componentOption.isInfinite;
        return (
          <div>
            {contentValue?.map((item: BaseFormComponent, i: number) => {
              return (
                <div>
                  <div>{isInfinite ? component?.label + (i + 1) : ""}</div>
                  <div>
                    {component.componentOption.children?.map(
                      (child: BaseFormComponent) => {
                        return (
                          <div key={child.key}>
                            <Space>
                              <div>{child.label}：</div>
                              {
                                //@ts-ignore
                                renderFormContentByType(child, item[child.key])
                              }
                            </Space>
                          </div>
                        );
                      }
                    )}
                  </div>
                </div>
              );
            })}
          </div>
        );
      }
      default:
        return <div>{contentValue}</div>;
    }
  };
  const Desc_option = useMemo(() => {
    return config?.map((v: any) => {
      return {
        key: v.key,
        label: v.label,
        children: renderFormContentByType(v) ?? "无",
      };
    });
  }, [config, data]);
  return (
    <div>
      <Descriptions title="" size="small" column={1} items={Desc_option} />
    </div>
  );
};

export default Content;
