import styles from "./review.module.css";
import ProcessTimeLine from "./timeLine";
import {
  Button,
  Flex,
  Image,
  Upload,
  UploadProps,
  Input,
  ConfigProvider,
  message,
  Form,
  Select,
  Modal,
} from "antd";
import wodeshengqing from "@/assets/images/applyRecord/wodeshengqing.png";

import {
  CheckOutlined,
  CloseOutlined,
  DoubleRightOutlined,
  FormOutlined,
  PlusOutlined,
} from "@ant-design/icons";

import { useMemo, useState } from "react";
import service from "@/service";
import eventBus from "@/utils/eventBus";
import BasicModal from "@/components/BasicModal";
import { inversionSerializationRule } from "@/customForm/utils";
import GroupCard from "../User/SubmitApplication/components/groupCard";
import RenderComponent from "@/components/FormComponentRender/renderComponent";
import { composeImgUrl } from "@/utils";

const Header = () => {
  return (
    <Flex align="center" gap={12} className={styles.header}>
      <img src={wodeshengqing} alt="" style={{ width: 46, height: 46 }}></img>
      <div className={styles.modalTitle}>办理事项</div>
    </Flex>
  );
};

interface ReviewProps {
  detail: any;
  actionObj: any;
  configSource: any;
  modalOpt?: any;
}
const Review = (props: ReviewProps) => {
  const { detail, modalOpt, actionObj, configSource } = props;

  const [inputStr, setInputStr] = useState("");

  const [fileList, setFileList] = useState<string[]>([]);

  const forwardAndReverseName =
    actionObj?.forwardAndReverseName?.split(",") ?? [];

  const [openDealModal, setOpenDealModal] = useState(false);

  const [form] = Form.useForm();

  const nodeType = actionObj?.nodeType?.value;

  const [userList, setUserList] = useState<any[]>([]);

  const [selectUserModal, setSelectUserModal] = useState(false);

  const formConfig = useMemo(() => {
    const matterContentList = configSource?.matterContentList;

    if (matterContentList && actionObj?.examineKeys) {
      let temp = matterContentList
        .sort((pre: any, cur: any) => pre.sort - cur.sort)
        .map((item: any) => {
          return {
            ...item,
            componentOption: item.otherSet ? JSON.parse(item.otherSet) : {},
            key: item.fieldKey,
            validationRules: inversionSerializationRule(item.validationRules),
          };
        });
      /** 过滤需要处理的内容 */
      if (actionObj?.examineKeys !== "all") {
        const keys = actionObj?.examineKeys?.split(",") ?? [];
        temp = temp.filter((item: any) => keys.includes(item.fieldKey));
      } else {
        return [];
      }
      return temp;
    }
    return [];
  }, [configSource, actionObj]);
  const handleChange: UploadProps["onChange"] = ({ file }) => {
    if (file.status === "done") {
      const imgStr = file.response.data;
      setFileList([...fileList, imgStr]);
    }
  };

  const remakeChange = (e: any) => {
    const value = e.target.value;
    setInputStr(value);
  };

  const submitReverse = (tagName: string) => {
    const formData = new FormData();
    formData.append("taskId", actionObj?.taskId);
    formData.append("approveComment", inputStr);
    formData.append("attachmentList", fileList.join(";"));
    formData.append("approvePass", "0");
    formData.append("operationName", tagName);

    service.managementService.completeExamine(formData).then((res) => {
      if (res.code === 200) {
        message.success("审批完成");
        eventBus.emit("updateTableList");
      }
    });
  };

  const submitExamine = (tagName: string, optional = false) => {
    form.validateFields().then((values) => {
      const { enableSelectNextNodeUser = false } = actionObj;
      const formData = new FormData();
      formData.append("taskId", actionObj?.taskId);
      formData.append("approveComment", inputStr);
      formData.append("attachmentList", fileList.join(";"));
      formData.append("operationName", tagName);

      if (nodeType === 3 || nodeType === 5) {
        formData.append("approvePass", optional ? "2" : "1");
      }

      const params = [] as any[];
      for (const key in values) {
        const itemConfig = configSource?.matterContentList?.find(
          (v: any) => v.fieldKey === key
        );
        params.push({
          contentId: key,
          content: values[key],
          applicantRecordId: actionObj.id,
          downFlag:
            itemConfig.componentType === "FileUpload" ||
            itemConfig.componentType === "ImgUpload"
              ? true
              : false,
        });
      }

      const submit = () => {
        service.managementService.submitForm({
          thingId: actionObj.thingId,
          reportContents: params,
        });

        service.managementService.completeExamine(formData).then((res) => {
          if (res.code === 200) {
            message.success("审批完成");
            eventBus.emit("updateTableList");
          }
        });
      };

      if (enableSelectNextNodeUser) {
        service.managementService.getNextNodeUser(formData).then((res) => {
          if (res.data?.nextUsers.length === 0) {
            submit();
            return;
          }
          const option = res.data.nextUsers.map((v: any) => {
            return {
              ...v,
              value: v.id,
              label: v.username,
            };
          });

          let userId!: string;
          Modal.confirm({
            title: `选择${res.data.nodeNameAlias}处理人`,
            content: (
              <Select
                style={{ width: "100%" }}
                onChange={(id) => {
                  userId = id;
                }}
                options={option}
              />
            ),
            onOk() {
              if (userId) {
                formData.append("fixUser", userId);

                submit();
              } else {
                message.error("请选择下一节点处理人");
              }
            },
            onCancel() {},
          });
        });
        return;
      }

      submit();
    });
  };

  const deleteImg = (item: string) => {
    const imgList = fileList.filter((v) => v !== item);
    setFileList(imgList);
  };

  return (
    <div className={styles.container}>
      <BasicModal
        visible={openDealModal}
        width={600}
        zIndex={1001}
        contentStyle={{ borderRadius: 10, maxHeight: 700 }}
        onClose={function (): void {
          setOpenDealModal(false);
        }}
      >
        <Header />
        <div className={styles.modalBody}>
          <Form form={form} colon={false} layout="vertical">
            {formConfig?.length > 0 && (
              <GroupCard title={""}>
                {formConfig.map((item: any) => {
                  return (
                    <Form.Item
                      label={item.label}
                      name={item.key}
                      key={item.key}
                      rules={[
                        {
                          required: item.componentOption?.require,
                          message: `请填写${item?.label}`,
                        },
                        ...item.validationRules,
                      ]}
                    >
                      <RenderComponent
                        config={item.componentOption}
                        componentType={item.componentType}
                        metaData={item}
                      ></RenderComponent>
                    </Form.Item>
                  );
                })}
              </GroupCard>
            )}

            <GroupCard title={""}>
              <Form.Item label="审批意见">
                <div className={styles.editContent}>
                  <ConfigProvider
                    theme={{
                      components: {
                        Input: {
                          activeBg: "#f3f6fb",
                          activeBorderColor: "#f3f6fb",
                          activeShadow: "unset",
                        },
                      },
                    }}
                  >
                    <Input.TextArea
                      placeholder="填写审批意见"
                      onChange={remakeChange}
                      style={{
                        border: 0,
                        backgroundColor: "#f3f6fb",
                      }}
                    />
                  </ConfigProvider>
                  <Flex gap={12}>
                    {fileList.map((item) => {
                      return (
                        <div className={styles.imgItem}>
                          <div
                            className={styles.closeIcon}
                            onClick={() => deleteImg(item)}
                          >
                            <CloseOutlined style={{ color: "red" }} />
                          </div>
                          <Image
                            width={36}
                            height={36}
                            style={{ borderRadius: 4 }}
                            src={composeImgUrl(item)}
                          ></Image>
                        </div>
                      );
                    })}
                    <Upload
                      action="/apis/oss/upload?bucketName=cgtf"
                      showUploadList={false}
                      accept="image/*"
                      maxCount={1}
                      onChange={handleChange}
                    >
                      <div className={styles.btn}>
                        <PlusOutlined />
                      </div>
                    </Upload>
                  </Flex>
                </div>
              </Form.Item>
            </GroupCard>
            <Form.Item>
              <Flex style={{ marginTop: 18 }} gap={14}>
                {nodeType === 2 && (
                  <Button
                    icon={<CheckOutlined />}
                    iconPosition="start"
                    type="text"
                    size="large"
                    onClick={() => submitExamine("通过")}
                    style={{
                      backgroundColor: "#EDF1F7",
                      color: "rgba(46, 108, 255, 1)",
                    }}
                  >
                    通过
                  </Button>
                )}
                {nodeType === 3 && (
                  <>
                    <Button
                      icon={<CheckOutlined />}
                      iconPosition="start"
                      type="text"
                      size="large"
                      onClick={() => submitExamine(forwardAndReverseName[0])}
                      style={{
                        backgroundColor: "#EDF1F7",
                        color: "rgba(46, 108, 255, 1)",
                      }}
                    >
                      {forwardAndReverseName[0]}
                    </Button>
                    <Button
                      type="text"
                      icon={<CloseOutlined />}
                      iconPosition="start"
                      size="large"
                      onClick={() => submitReverse(forwardAndReverseName[1])}
                      style={{
                        backgroundColor: "#EDF1F7",
                        color: "rgba(252, 74, 99, 1)",
                      }}
                    >
                      {forwardAndReverseName[1]}
                    </Button>
                  </>
                )}
                {nodeType === 5 && (
                  <>
                    <Button
                      icon={<CheckOutlined />}
                      iconPosition="start"
                      type="text"
                      size="large"
                      onClick={() => submitExamine(forwardAndReverseName[1])}
                      style={{
                        backgroundColor: "#EDF1F7",
                        color: "rgba(46, 108, 255, 1)",
                      }}
                    >
                      {forwardAndReverseName[1]}
                    </Button>
                    <Button
                      icon={<DoubleRightOutlined />}
                      iconPosition="start"
                      type="text"
                      size="large"
                      onClick={() =>
                        submitExamine(forwardAndReverseName[0], true)
                      }
                      style={{
                        backgroundColor: "#EDF1F7",
                        color: "rgba(46, 108, 255, 1)",
                      }}
                    >
                      {forwardAndReverseName[0]}
                    </Button>
                    <Button
                      type="text"
                      icon={<CloseOutlined />}
                      iconPosition="start"
                      size="large"
                      onClick={() => submitReverse(forwardAndReverseName[2])}
                      style={{
                        backgroundColor: "#EDF1F7",
                        color: "rgba(252, 74, 99, 1)",
                      }}
                    >
                      {forwardAndReverseName[2]}
                    </Button>
                  </>
                )}
              </Flex>
            </Form.Item>
          </Form>
        </div>
      </BasicModal>
      <div className={styles.timeLineWrapper}>
        <ProcessTimeLine detail={detail}></ProcessTimeLine>
      </div>
      {modalOpt?.type === "edit" && (
        <div className={styles.editWrapper}>
          <Button
            icon={<FormOutlined />}
            iconPosition="start"
            type="text"
            size="large"
            onClick={() => {
              setOpenDealModal(true);
            }}
            style={{
              backgroundColor: "#EDF1F7",
              color: "rgba(46, 108, 255, 1)",
            }}
          >
            办理
          </Button>
        </div>
      )}
    </div>
  );
};

export default Review;
