import { Flex, Timeline, Image, Tag } from "antd";
import DecoratePoint from "./components/decoratePoint";
import styles from "./timeLine.module.css";
import service from "@/service";
import { useEffect, useMemo, useState } from "react";
import { composeImgUrl, downloadFile } from "@/utils";
import { FileUnknownOutlined } from "@ant-design/icons";

interface ProcessTimeLineProps {
  detail: any;
}
const ProcessTimeLine = (props: ProcessTimeLineProps) => {
  const { detail } = props;

  const [dataSource, setDataSource] = useState<any[]>([]);

  const getData = () => {
    if (detail?.id) {
      service.managementService.getExamineHistory(detail.id).then((res) => {
        if (res.code === 200) {
          setDataSource(res.data);
        }
      });
    }
  };
  const renderTag = (v: any) => {
    if (v.nodeName === "申请人") {
      return undefined;
    }
    if (v.nodeType?.value === 2) {
      return undefined;
    }
    return (
      <Tag color={v?.approveStatus?.value != 0 ? "#87d068" : "red"}>
        {v.operationName ?? v.approveStatus?.name}
      </Tag>
    );
  };

  const items = useMemo(() => {
    return dataSource.map((v) => {
      let status = false;

      if (v.current) {
        status = true;
      }
      if (v.approveTime) {
        status = true;
      }
      const attachments = v.attachments;

      const element = (
        <div>
          <Flex align="center" className={styles.title} gap={12}>
            {v.nodeName + " " + (v?.approveUserName ?? "")}
            {renderTag(v)}
          </Flex>
          <div className={styles.time}>{v.approveTime}</div>
          {v.current && v.nodeCode !== "END" && v.nodeCode !== "REJECT" ? (
            <Flex
              className={styles.remake}
              align="center"
              justify="space-between"
            >
              <div style={{ color: "rgba(1, 179, 110, 1)" }}>审批中...</div>
            </Flex>
          ) : undefined}
          {v?.approveComment && v.approveComment?.length > 0 && (
            <Flex className={styles.remake} vertical>
              <div>{v.approveComment}</div>
              <Flex style={{ marginTop: 12 }} gap={8}>
                {attachments?.map((attachment: any) => {
                  let fileType = "none";
                  if (attachment && attachment.length > 0) {
                    const strList = attachment?.split(".") ?? [];
                    const extra = strList[strList.length - 1];

                    if (extra === "pdf") {
                      fileType = "pdf";
                    }
                    if (
                      extra === "jpg" ||
                      extra === "png" ||
                      extra === "jpeg"
                    ) {
                      fileType = "img";
                    } else {
                      fileType = "other";
                    }
                  }
                  return (
                    <>
                      {fileType === "pdf" && (
                        <div
                          className={styles.noValueStatus}
                          onClick={() => {
                            window.open(composeImgUrl(attachment));
                          }}
                        >
                          pdf
                        </div>
                      )}
                      {fileType === "other" && (
                        <div
                          className={styles.noValueStatus}
                          onClick={() => {
                            downloadFile(composeImgUrl(attachment), "附件");
                          }}
                        >
                          <FileUnknownOutlined />
                        </div>
                      )}
                      {fileType === "img" && (
                        <Image
                          width={40}
                          height={40}
                          style={{ borderRadius: 4 }}
                          src={composeImgUrl(attachment)}
                        ></Image>
                      )}
                    </>
                  );
                })}
              </Flex>
            </Flex>
          )}
        </div>
      );

      return {
        dot: <DecoratePoint type={status ? 2 : 1} />,
        children: element,
      };
    });
  }, [dataSource]);

  useEffect(() => {
    getData();
  }, [detail]);

  return (
    <div>
      <Timeline items={items} />
    </div>
  );
};

export default ProcessTimeLine;
