import {
  Button,
  Dropdown,
  Flex,
  Form,
  Input,
  MenuProps,
  Modal,
  Space,
  message,
} from "antd";
import { useNavigate } from "react-router-dom";

import BasicModal from "@/components/BasicModal";
import avatarIcon from "@/assets/images/user/avatar.png";
import flowIcon from "@/assets/images/user/flow.png";
import styles from "./login.module.css";
import { useBoolean } from "ahooks";
import service from "@/service";
import useUserStore from "@/store/useUserStore";
import { useEffect, useState } from "react";
import { LogoutOutlined } from "@ant-design/icons";
import { encryption } from "@/utils";
import { getApplyStatisc } from "@/service/applyController";

const Login: React.FC = () => {
  const [visible, { setFalse, setTrue }] = useBoolean(false);
  const [form] = Form.useForm<{
    username: string;
    password: string;
  }>();

  const { userInfo, updateUserInfo } = useUserStore();
  const [recordListNum, setRecordListNum] = useState(0);

  const navigate = useNavigate();
  const onLogin = (values: any) => {
    const params = {
      ...values,
    };
    params.password = encryption(values.password || "", "thanks,hncycloud");

    service.loginService.getUserToken(params).then((res) => {
      if (res.code === 200) {
        service.loginService.loginIpCheck().then((res)=>{
            if(res.code !== 200){
                Modal.warning({
                    title:'登录异常提醒',
                    content:'尊敬的用户，我们检测到您本次登录的 IP 地址与以往不同， 请您确认是否为本人操作。若不是您本人操作，请及时联系我们的客服人员。'
                })
            }
        })
        /** 存储token */
        localStorage.setItem("user_token", res.data.access_token);
        /** 以用户平台的token获取本身平台的信息 */
        service.loginService
          .getUserProfileInfo()
          .then((userRes) => {
            if (userRes.code === 200) {
              updateUserInfo(userRes.data.appUser);
              setFalse();
              getStatisc()
              message.success("登录成功！");
            } else {
              message.error("登录成功！");
            }
          })
          .catch(() => {
            message.error("账号或密码错误");
          });
      }
    });
  };

  useEffect(() => {
    const mobile = userInfo?.mobile;

    if (mobile) {
      service.applyService
        .getExamineProgress({
          pageNum: 1,
          pageSize: 100,
          loginName: mobile,
        })
        .then((res) => {
          if (res.code === 200) {
            setRecordListNum(res.data.total);
          }
        });
    }
  }, [userInfo]);
  const items: MenuProps["items"] = [
    {
      key: "1",
      label: (
        <Space>
          <LogoutOutlined />
          退出登录
        </Space>
      ),
    },
  ];
  const onLogout = (item: any) => {
    if (item.key === "1") {
      updateUserInfo(undefined);
      localStorage.removeItem("user_token");
    }
  };

  const checkProgress = () => {
    if (recordListNum === 0) {
      message.info("无申请记录");
      return;
    }
    navigate("/apply-record");
  };
  console.log(userInfo);

  const [applyStatisc,setApplystatisc] = useState<any>({})
  const getStatisc = async ()=>{
    const res= await getApplyStatisc()
    if(res.code === 200){
        setApplystatisc(res.data)
    }
  }
  return (
    <>
      {userInfo ? (
        <Space size="large">
          <Flex className={styles.statisc} gap={20}>
            <div>共申请事项：<span>{applyStatisc.total}</span>项</div>
            <div>已办结事项：<span>{applyStatisc.completed}</span>项</div>
          </Flex>
          <div onClick={checkProgress}>
            <img src={flowIcon} alt="" style={{ width: 30, height: 32 }} />
          </div>
          <Dropdown menu={{ items, onClick: onLogout }}>
            <Space style={{ cursor: "pointer" }}>
              <Flex align="center">
                <img
                  src={avatarIcon}
                  alt=""
                  style={{ width: 55, height: 55 }}
                />
                <div>{userInfo?.nickname}</div>
              </Flex>
            </Space>
          </Dropdown>
        </Space>
      ) : (
        <Button onClick={setTrue} type="primary">
          登录
        </Button>
      )}

      <BasicModal
        width={1155}
        visible={visible}
        height={739}
        onClose={setFalse}
        contentStyle={{ borderRadius: 10 }}
      >
        <div className={styles.container}>
          <div></div>
          <div>
            <div className={styles.title}>欢迎登录</div>
            <div>
              <Form
                layout="vertical"
                form={form}
                requiredMark={false}
                onFinish={onLogin}
              >
                <Form.Item
                  hasFeedback
                  label="账号"
                  name="username"
                  validateDebounce={1000}
                  rules={[{ required: true, message: "请输入账号" }]}
                >
                  <Input placeholder="请输入账号" size="large" />
                </Form.Item>
                <Form.Item
                  hasFeedback
                  label="密码"
                  name="password"
                  validateDebounce={1000}
                  rules={[{ required: true, message: "请输入密码" }]}
                >
                  <Input.Password placeholder="请输入密码" size="large" />
                </Form.Item>
                <Form.Item>
                  <Button
                    type="primary"
                    shape="round"
                    onClick={form.submit}
                    style={{ width: 120, height: 46 }}
                  >
                    登录
                  </Button>
                </Form.Item>
              </Form>
            </div>
          </div>
        </div>
      </BasicModal>
    </>
  );
};

export default Login;
