import BasicModal from "@/components/BasicModal";
import styles from "./add-modal.module.css";
import { Button, Flex, Radio, RadioChangeEvent, Select, message } from "antd";
import { useEffect, useState } from "react";
import UserSelect from "@/customForm/components/UserSelect";
import ProjectSelect from "./components/projectSelect";
import service from "@/service";

const adminTypes = [
  {
    name: "超级管理员",
    value: "SUPPER",
  },
  {
    name: "区级管理员",
    value: "AREA",
  },
  {
    name: "街道管理员",
    value: "STREET",
  },
];

interface PropTypes {
  visible: boolean;
  onClose(): void;
}
export default function (props: PropTypes) {
  const { visible, onClose } = props;
  const [adminType, setAdminType] = useState("SUPPER");
  const [streetList, setStreetList] = useState<API.Street[]>([]);
  const [adminContent, setAdminContent] = useState<{
    streetIds?: string[];
    /** 人员 */
    peoples?: string[];
    projectIds: string;
  }>({ projectIds: "all" });

  const [adminName, setAdminName] = useState("");
  const [options, setOptions] = useState<any[]>([]);

  useEffect(() => {
    if (visible) {
      service.commonService.getAllStreet().then((res) => {
        if (res.code === 200) {
          const config = res.data.map((v) => {
            return { ...v, value: v.code, label: v.name };
          });

          setStreetList(config);
        }
      });
      service.managementService.getAllApplication().then((res) => {
        if (res.code === 200) {
          const list = res.data.list;
          const newOptions = list.map((item: any) => ({
            label: item.thingName,
            value: item.id,
          }));
          setOptions(newOptions);
        }
      });
    }
  }, [visible]);

  const init = () => {
    setAdminContent({
      projectIds: "all",
    });
    setAdminType("SUPPER");
  };

  const typeChange = (e: RadioChangeEvent) => {
    setAdminType(e.target.value);
    /** 重置内容 */
    setAdminContent({
      projectIds: "all",
    });
  };

  const addAdmin = () => {
    if (!adminContent.peoples) {
      message.error("请选择管理员");
      return;
    }

    if (adminType === "street") {
      if (!adminContent.streetIds) {
        message.error("请选择管理的街道");
        return;
      }
    }
    const params = {
      roleType: adminType,
      roleName: adminTypes.find((v) => v.value === adminType)?.name,
      roleDesc: "",
      userName: adminName,
      userId: adminContent.peoples.join(","),
      streetCode: adminContent.streetIds?.join(","),
      streetName: adminContent.streetIds
        ?.map((v) => streetList.find((street: any) => street.code === v)?.name)
        .join(","),
      thingId: adminContent.projectIds === "all" ? "" : adminContent.projectIds,
      thingName:
        adminContent.projectIds === "all"
          ? ""
          : adminContent.projectIds
              .split(",")
              ?.map(
                (v) =>
                  options.find((project: any) => project.value === v)?.label
              )
              .join(","),
    };

    service.commonService
      .addAdmin(params)
      .then((res) => {
        if (res.code === 200) {
          message.success("添加成功");
          init();
          onClose();
        }
      })
      .catch(() => {
        message.warning("设置失败");
      });
  };
  return (
    <>
      <BasicModal
        visible={visible}
        width={600}
        contentStyle={{ borderRadius: 10 }}
        height={600}
        zIndex={100}
        onClose={onClose}
      >
        <div className={styles.container}>
          <div className={styles.header}>
            <div className={styles.headerTitle}>添加管理员</div>
          </div>
          <div className={styles.modalBody}>
            <div className={styles.formItem}>
              <div className={styles.formItemTitle}>请选择管理员类型</div>
              <Radio.Group onChange={typeChange} value={adminType}>
                {adminTypes.map((item) => (
                  <Radio key={item.value} value={item.value}>
                    {item.name}
                  </Radio>
                ))}
              </Radio.Group>
            </div>

            {adminType === "SUPPER" && (
              <div className={styles.formItem}>
                <div className={styles.formItemTitle}>选择人员</div>
                <div>
                  <UserSelect
                    value={adminContent.peoples}
                    onChange={function (values: string[]): void {
                      setAdminContent({
                        ...adminContent,
                        peoples: values,
                      });
                    }}
                    onChangeName={setAdminName}
                    max={1}
                  ></UserSelect>
                </div>
              </div>
            )}

            {adminType === "AREA" && (
              <div>
                <div className={styles.formItem}>
                  <div className={styles.formItemTitle}>管理事项</div>
                  <div>
                    <ProjectSelect
                      options={options}
                      value={adminContent.projectIds}
                      onChange={function (value: string): void {
                        setAdminContent({
                          ...adminContent,
                          projectIds: value,
                        });
                      }}
                    ></ProjectSelect>
                  </div>
                </div>
                <div className={styles.formItem}>
                  <div className={styles.formItemTitle}>选择人员</div>
                  <div>
                    <UserSelect
                      value={adminContent.peoples}
                      onChange={function (values: string[]): void {
                        setAdminContent({
                          ...adminContent,
                          peoples: values,
                        });
                      }}
                      onChangeName={setAdminName}
                      max={1}
                    ></UserSelect>
                  </div>
                </div>
              </div>
            )}

            {adminType === "STREET" && (
              <div>
                <div className={styles.formItem}>
                  <div className={styles.formItemTitle}>选择管理的街镇</div>
                  <div>
                    <Select
                      onChange={function (value: string[]): void {
                        setAdminContent({
                          ...adminContent,
                          streetIds: value,
                        });
                      }}
                      style={{ width: 300 }}
                      value={adminContent.streetIds}
                      mode="multiple"
                      options={streetList}
                    ></Select>
                  </div>
                </div>
                <div className={styles.formItem}>
                  <div className={styles.formItemTitle}>管理事项</div>
                  <div>
                    <ProjectSelect
                      options={options}
                      value={adminContent.projectIds}
                      onChange={function (value: string): void {
                        setAdminContent({
                          ...adminContent,
                          projectIds: value,
                        });
                      }}
                    ></ProjectSelect>
                  </div>
                </div>
                <div className={styles.formItem}>
                  <div className={styles.formItemTitle}>选择人员</div>
                  <div>
                    <UserSelect
                      value={adminContent.peoples}
                      onChange={function (values: string[]): void {
                        setAdminContent({
                          ...adminContent,
                          peoples: values,
                        });
                      }}
                      onChangeName={setAdminName}
                      max={1}
                    ></UserSelect>
                  </div>
                </div>
              </div>
            )}

            <Flex gap={16}>
              <Button block type="primary" size="large" onClick={addAdmin}>
                添加
              </Button>
              <Button block size="large">
                取消
              </Button>
            </Flex>
          </div>
        </div>
      </BasicModal>
    </>
  );
}
