import { useEffect, useState } from "react";

import { Radio, RadioChangeEvent } from "antd";
import Checkbox from "@/customForm/components/Checkbox";
import styles from "./projectSelect.module.css";
import { isEqual } from "lodash";

interface FormSelectProps {
  value: "all" | string;
  onChange: (value: string) => void;
  options: any;
}

const FormSelect = (props: FormSelectProps) => {
  const { value, onChange, options } = props;

  const [selected, setSelected] = useState<string>("");
  const [selectedMode, setSelectedMode] = useState("all");

  const modeChange = (e: RadioChangeEvent) => {
    if (e.target.value === "all") {
      onChange("all");
    } else {
      setSelected("");
      onChange("");
    }

    setSelectedMode(e.target.value);
  };
  useEffect(() => {
    if (!value) {
      return;
    }
    if (value === "all") {
      setSelected("");
      setSelectedMode("all");
      return;
    }

    if (isEqual(value, selected)) {
      return;
    }
    setSelected(value);
    setSelectedMode("parts");
  }, [value]);

  const onCheckChange = (params: string) => {
    setSelected(params);
    onChange(params);
  };

  return (
    <div>
      <div style={{ height: 32 }}>
        <Radio.Group onChange={modeChange} value={selectedMode}>
          <Radio value={"all"}>全部事项</Radio>
          <Radio value={"parts"}>部分事项</Radio>
        </Radio.Group>
      </div>

      {selectedMode === "parts" && (
        <div className={styles.checkboxWrapper}>
          <Checkbox
            value={selected}
            onChange={onCheckChange as any}
            options={options}
          ></Checkbox>
        </div>
      )}
    </div>
  );
};

export default FormSelect;
