import BasicModal from "@/components/BasicModal";
import styles from "./index.module.css";
import { TableProps, Space, Table, Button, message } from "antd";
import AddModal from "./add-modal";
import { useBoolean } from "ahooks";
import { PlusOutlined } from "@ant-design/icons";
import { useEffect, useState } from "react";
import service from "@/service";
interface PropTypes {
  visible: boolean;
  onClose(): void;
}
export default function (props: PropTypes) {
  const { visible, onClose } = props;

  const [addVisible, addVisibleAction] = useBoolean(false);
  const [dataSource, setDataSource] = useState<any[]>([]);

  const init = () => {
    setDataSource([]);

    service.commonService.getRoleOfAuthority().then((res) => {
      if (res.code === 200) {
        setDataSource(res.data);
      }
    });
  };

  useEffect(() => {
    if (visible) {
      init();
    }
  }, [visible]);

  const deleteRole = (record: any) => {
    service.commonService.deleteAdmin(record.roleCode).then((res) => {
      if (res.code === 200) {
        init();
        message.success("删除成功");
      }
    });
  };
  const columns: TableProps<any>["columns"] = [
    {
      title: "序号",
      key: "index",
      render: (_, __, i) => <div>{i + 1}</div>,
    },
    {
      title: "管理员姓名",
      dataIndex: "userName",
      render: (_, __) => <div>{_ ?? "暂无姓名"}</div>,
    },
    {
      title: "管理员类别",
      dataIndex: "roleName",
    },

    {
      title: "管理事项",
      dataIndex: "thingName",
      key: "thingName",
      render(value) {
        if (value.length == 0) {
          return <div>全部</div>;
        }
        return (
          <div>
            {value.map((v: string) => (
              <div>{v}</div>
            ))}
          </div>
        );
      },
    },
    {
      title: "管理街镇",
      key: "streetName",
      dataIndex: "streetName",
      render(value) {
        if (!value) {
          return "无";
        }
        return (
          <div>
            {value?.split(",").map((v: string) => (
              <div>{v}</div>
            ))}
          </div>
        );
      },
    },
    {
      title: "操作",
      key: "action",
      render: (_, record) => (
        <Space size="middle">
          <a onClick={() => deleteRole(record)}>删除</a>
        </Space>
      ),
    },
  ];

  useEffect(() => {
    service.commonService.getRoleOfAuthority().then((res) => {
      if (res.code === 200) {
      }
    });
  }, []);

  return (
    <>
      <AddModal
        visible={addVisible}
        onClose={() => {
          init();
          addVisibleAction.setFalse();
        }}
      ></AddModal>
      <BasicModal
        visible={visible}
        width={1600}
        contentStyle={{ borderRadius: 10 }}
        height={1000}
        onClose={onClose}
      >
        <div className={styles.container}>
          <div className={styles.header}>
            <div className={styles.headerTitle}>审批通管理员</div>
            <Button
              type="primary"
              shape="circle"
              onClick={addVisibleAction.setTrue}
              icon={<PlusOutlined />}
            ></Button>
          </div>
          <div className={styles.modalBody}>
            <Table
              columns={columns}
              dataSource={dataSource}
              pagination={false}
            />
          </div>
        </div>
      </BasicModal>
    </>
  );
}
