import ReactECharts from 'echarts-for-react'
import { CSSProperties, FC, useEffect, useState } from "react"
import { EChartsOption } from 'echarts'
import { Flex } from 'antd'
import styles from './LineChart.module.css'
import TabSwitch from '@/components/TabSwitch'
import { getStatusTrend } from '@/service/approveVisual'

type lineChartProps = {
    style?: CSSProperties
    // xData: string[]
    // data: { data: number[], color: string, name: string }[]
}

const tabOptions = [
    { label: '月', value: 'month' },
    { label: '周', value: 'week' },
    { label: '日', value: 'day' },
]

type dataType = { data: number[], color: string, name: string }
const LineChart: FC<lineChartProps> = (props) => {
    const { style } = props
    const [option, setOption] = useState<EChartsOption>({})

    const [xData, setXdata] = useState<string[]>([])
    const [data, setData] = useState<dataType[]>([])
    const [dateType, setDateType] = useState(tabOptions[0].value)
    const getData = async () => {
        const res = await getStatusTrend(dateType)
        if (res.code === 200) {
            const { approveRecordStatusStatistics, endRecordStatusStatistics, rejectRecordStatusStatistics } = res.data
            const xData: string[] = []
            const datas: dataType[] = []
            datas[0] = {
                data: approveRecordStatusStatistics.map(({ value, name }: any) => {
                    if (!xData.includes(name)) { xData.push(name) }
                    return value
                }),
                color: '#1FD38D',
                name: '处理中'
            }
            datas[1] = {
                data: endRecordStatusStatistics.map(({ value, name }: any) => {
                    if (!xData.includes(name)) { xData.push(name) }
                    return value
                }),
                color: '#007AFF',
                name: '完成'
            }
            datas[2] = {
                data: rejectRecordStatusStatistics.map(({ value, name }: any) => {
                    if (!xData.includes(name)) { xData.push(name) }
                    return value
                }),
                color: '#FFBD55',
                name: '驳回'
            }

            setXdata(xData.sort())
            setData(datas)
        }
    }
    useEffect(() => {
        getData()
    }, [dateType])

    useEffect(() => {
        if (data.length === 0) {
            setOption({})
        } else {
            const series: EChartsOption['series'] = data.map((v) => {
                return {
                    ...v,
                    type: 'line',
                    smooth: true,
                    lineStyle: { width: 3 },
                    areaStyle: {},
                    showSymbol: false,
                    stack: 'Total',
                    emphasis: { focus: 'series' }
                }
            })
            const option: EChartsOption = {
                legend: {
                    icon: 'circle',
                    itemHeight: 10,
                    itemGap: 25,
                    textStyle: {
                        fontFamily: 'PingFang SC',
                        fontWeight: 500,
                        fontSize: 16,
                        color: '#757C7F',
                        padding: [0, 0, 0, -5]
                    }
                },
                grid: { bottom: 30 },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'cross',
                        label: { backgroundColor: '#6a7985' }
                    }
                },
                // dataZoom: [
                //     {
                //         type: 'slider',
                //         show: true,
                //         realtime: true,
                //         start: 0,
                //         end: 100
                //     },
                //     {
                //         type: 'inside'
                //     }
                // ],
                xAxis: {
                    data: xData,
                    boundaryGap: false,
                    axisLine: { show: false },
                    axisTick: { show: false },
                    axisLabel: {
                        // interval: 0,
                        formatter: function (params) {
                            let newParamsName = '';
                            const paramsNameNumber = params.length; // 文字总长度
                            const provideNumber = 10; //一行显示几个字
                            const rowNumber = Math.ceil(paramsNameNumber / provideNumber);
                            if (paramsNameNumber > provideNumber) {
                                for (let p = 0; p < rowNumber; p++) {
                                    const start = p * provideNumber;
                                    const end = start + provideNumber;
                                    const tempStr = p === rowNumber - 1 ? params.substring(start, paramsNameNumber) : params.substring(start, end) + '\n';
                                    newParamsName += tempStr;
                                }
                            } else {
                                newParamsName = params;
                            }
                            return newParamsName;
                        }
                    }
                },
                yAxis: {
                    type: 'value'
                },
                series
            }
            setOption(option)
        }
    }, [xData, data])

    return <Flex className={styles.chartBox} style={{ ...style }} vertical gap={20}>
        <Flex className={styles.title} align='center' justify='space-between'>
            状态趋势
            <TabSwitch
                defaultId={tabOptions[0].value}
                options={tabOptions}
                onSelect={(val) => { setDateType(val as string) }}
            />
        </Flex>
        <ReactECharts
            style={{ width: '100%', height: '100%' }}
            notMerge={true}
            lazyUpdate={true}
            option={option}
        />
    </Flex>
}

export default LineChart