import styles from "./index.module.css";
import ItemCard from "./itemCard";
import { Button, Flex, Modal } from "antd";
import Setting from "@/pages/Setting";
import { useBoolean } from "ahooks";
import { useEffect, useState } from "react";
import service from "@/service";
import { PlusCircleOutlined } from "@ant-design/icons";
import eventBus from "@/utils/eventBus";
import AdminLogin from "@/pages/Login/adminLogin";
import useUserStore from "@/store/useUserStore";
import HomeEmpty from "@/components/HomeEmpty";
import AdministratorModal from "../AdministratorModal";
import ApproveVisual from "../ApproveVisual/ApproveVisual";
import SubjectDataVisual from "../SubjectDataVisual/SubjectDataVisual";

const ManagementMain = () => {
  const [visible, { setTrue, setFalse }] = useBoolean(false);
  const [adminModalOpen, adminModalOpenAction] = useBoolean(false);
  const [dataSource, setDataSource] = useState<any[]>([]);
  const { adminInfo, updateAdminAuth, isSuperAdmin } = useUserStore();
  const init = () => {
    setDataSource([]);
    if (adminInfo) {
      service.managementService.getAllApplication().then((res) => {
        if (res.code === 200) {
          setDataSource(res.data.list);
        }
      });
      service.commonService.getRoleOfAuthority().then((res) => {
        if (res.code === 200) {
          const auth = res.data?.find((v: any) => v.userId == adminInfo.id);

          if (auth && auth.roleName === "超级管理员") {
            updateAdminAuth(true);
          } else {
            updateAdminAuth(false);
          }
        }
      });
    }
  };

  useEffect(() => {
    init();
    const handleEvent = () => {
      init();
      setFalse();
    };
    eventBus.on("updateList", handleEvent);
    return () => {
      eventBus.off("updateList", handleEvent);
    };
  }, [adminInfo]);

  const onClose = () => {
    Modal.confirm({
      title: "确定要关闭嘛？",
      content: "你已填写的内容不会保存",
      onOk() {
        setFalse();
      },
    });
  };

  const [approveShow,setApproveShow] = useState(false)
  const [subjectDataShow,setSubjectDataShow] = useState(false)

  return (
    <div className={styles.container}>
      <Setting visible={visible} onClose={onClose} mode={"add"} />
      <AdministratorModal
        visible={adminModalOpen}
        onClose={adminModalOpenAction.setFalse}
      ></AdministratorModal>
      <div className={styles.header}>
        <Flex gap={12}>
          {isSuperAdmin && (
            <>
              <Button type="primary" onClick={()=>setSubjectDataShow(true)}>主体数据可视化</Button>
              <Button type="primary" onClick={()=>setApproveShow(true)}>审批通可视化</Button>
              <Button
                type="primary"
                icon={<PlusCircleOutlined />}
                onClick={adminModalOpenAction.setTrue}
              >
                添加管理员
              </Button>
              <Button
                type="primary"
                icon={<PlusCircleOutlined />}
                onClick={setTrue}
              >
                添加事项
              </Button>
            </>
          )}
          <AdminLogin />
        </Flex>
      </div>
      <div className={styles.contentWrapper}>
        <div className={styles.titleWrapper}>
          <div className={styles.title}>行政许可与行政备案</div>
        </div>

        <div className={styles.content}>
          {dataSource.length === 0 && (
            <div className={styles.emptyBox}>
              <HomeEmpty />
            </div>
          )}

          {dataSource?.map((item) => {
            return <ItemCard data={item} key={item.id}></ItemCard>;
          })}
        </div>
      </div>
      <ApproveVisual
        visible={approveShow}
        onClose={()=>setApproveShow(false)}
      />
      <SubjectDataVisual
        visible={subjectDataShow}
        onClose={()=>setSubjectDataShow(false)}
      />
    </div>
  );
};

export default ManagementMain;
