import { Flex, Space } from "antd";
import styles from "./itemCard.module.css";

import icon2 from "@/assets/images/icon/icon2.png";
import icon3 from "@/assets/images/icon/icon3.png";
import allIcon from "@/assets/images/management/icon1.png";
import rejectIcon from "@/assets/images/management/reject.png";
import successIcon from "@/assets/images/management/success.png";

import { useNavigate } from "react-router-dom";
import ArrowTag from "@/components/ArrowTag";
import { useMemo } from "react";
import { composeImgUrl } from "@/utils";
import { isUndefined } from "lodash";

const ItemCard: React.FC<{ data: any }> = (props) => {
  const { data } = props;
  const navigate = useNavigate();

  const clickHandler = (nodeInfo: any, type: "deal" | "manage") => {
    const id = nodeInfo.elementId ?? "";

    navigate(`/management/${data.id}?active=${id}&&type=${type}`);
  };

  const info = useMemo(() => {
    const manage =
      data?.nodeCount?.filter(
        (v: any) => v.elementId !== "APPROVAL" && v.elementId !== "APPROVED"
      ) ?? [];
    const deal =
      data?.nodeCount?.filter(
        (v: any) => v.elementId === "APPROVAL" || v.elementId === "APPROVED"
      ) ?? [];
    return {
      manage,
      deal,
    };
  }, [data]);

  const findNum = (key: string) => {
    if (info.deal.length > 0) {
      return info.deal.find((v: any) => v.elementId === key)?.elementCount ?? 0;
    }
    return 0;
  };

  const renderIcon = (params: { elementIcon?: string; elementId: string }) => {
    if (params.elementIcon && params.elementIcon.length > 0) {
      return composeImgUrl(params.elementIcon);
    }
    if (isUndefined(params.elementId)) {
      return allIcon;
    }
    if (params.elementId === "REJECT") {
      return rejectIcon;
    }
    if (params.elementId === "END") {
      return successIcon;
    }
  };

  return (
    <div className={styles.container}>
      <Flex gap={24} align="center" style={{ marginBottom: 12 }}>
        <img
          src={composeImgUrl(data?.icon ?? "")}
          alt=""
          style={{ width: 86, height: 86, borderRadius: 8 }}
        />
        <div className={styles.title}>{data.thingName}</div>
      </Flex>
      <Space>
        <ArrowTag
          text={data.thingType ? "行政许可" : "行政备案"}
          style={{ color: "rgba(0, 119, 255, 1)" }}
        ></ArrowTag>
        <ArrowTag
          text={data.implementingAgency}
          color="#FFE0B7"
          style={{
            color: "rgba(255, 128, 3, 1)",
          }}
        ></ArrowTag>
      </Space>
      <div>
        {info.manage.length > 0 && (
          <div>
            <div className={styles.listTitle}>我管理的</div>
            <div className={styles.list}>
              {info.manage.map((v: any, i: number) => {
                return (
                  <Flex
                    align="center"
                    key={v.elementId ?? i}
                    className={styles.itemStatus}
                    onClick={clickHandler.bind(this, v, "manage")}
                  >
                    <Flex align="center" gap={8}>
                      <img
                        alt=""
                        className={styles.img2}
                        src={renderIcon(v)}
                      ></img>
                      <div className={styles.itemName}>{v.elementName}</div>
                      <div className={styles.value}>{v.elementCount}</div>
                    </Flex>
                  </Flex>
                );
              })}
            </div>
          </div>
        )}
        {info.deal.length > 0 && (
          <div>
            <div className={styles.listTitle}>我办理的</div>
            <div className={styles.list}>
              <Flex
                align="center"
                justify="center"
                className={styles.leftBox}
                onClick={clickHandler.bind(
                  this,
                  { elementId: "APPROVAL" },
                  "deal"
                )}
              >
                <Flex align="center" gap={9}>
                  <img alt="" className={styles.img} src={icon3}></img>
                  <div>待处理</div>
                  <div>{findNum("APPROVAL")}</div>
                </Flex>
              </Flex>
              <Flex
                align="center"
                justify="center"
                className={styles.rightBox}
                onClick={clickHandler.bind(
                  this,
                  { elementId: "APPROVED" },
                  "deal"
                )}
              >
                <Flex align="center" gap={9}>
                  <img alt="" src={icon2} className={styles.img}></img>
                  <div>已处理</div>
                  <div>{findNum("APPROVED")}</div>
                </Flex>
              </Flex>
            </div>
          </div>
        )}
      </div>
    </div>
  );
};

export default ItemCard;
