import ArrowTag from "@/components/ArrowTag";
import { Flex, Popover, Space } from "antd";
import styles from "./index.module.css";
import { useLocation, useNavigate, useParams } from "react-router-dom";
import { RollbackOutlined, SettingOutlined } from "@ant-design/icons";
import ListTable from "./listTable";
import { useEffect, useState } from "react";
import service from "@/service";
import eventBus from "@/utils/eventBus";
import Setting from "@/pages/Setting";
import { useBoolean } from "ahooks";
import useUserStore from "@/store/useUserStore";
import { composeImgUrl } from "@/utils";
const IncludePopoverTag = ({
  title,
  content,
}: {
  title: string;
  content: string;
}) => {
  return (
    <Popover
      placement="bottom"
      content={<div style={{ maxWidth: 500 }}>{content}</div>}
    >
      <div className={styles.tag}>{title}</div>
    </Popover>
  );
};

const PendingReviewList = () => {
  const navigate = useNavigate();
  const { thingId } = useParams<{ thingId: string }>();

  const [applicationInfo, setApplicationInfo] = useState<any>();
  const location = useLocation();
  const searchParams = new URLSearchParams(location.search);
  const [showSettingModal, { setFalse, setTrue }] = useBoolean(false);
  const [config, setConfig] = useState({});
  const { isSuperAdmin } = useUserStore();
  const active = searchParams.get("active");
  const type = searchParams.get("type");
  const [settingMode, setSettingMode] = useState<"edit" | "add" | "view">(
    "edit"
  );
  const init = () => {
    service.managementService.getAllApplication(thingId).then((res) => {
      if (res.code === 200) {
        setApplicationInfo(res.data?.list?.[0]);
      }
    });
  };

  useEffect(() => {
    init();
  }, [thingId]);

  useEffect(() => {
    const handler = () => {
      init();
    };
    eventBus.on("updateTableList", handler);
    return () => eventBus.off("updateTableList", handler);
  }, []);

  const openSetting = () => {
    if (thingId) {
      /** 寻找到全部的数量 */

      service.settingService.getTemplateConfig(thingId).then((res1) => {
        if (res1.code === 200) {
          service.managementService
            .getAllRecordByThingId(thingId)
            .then((res) => {
              if (res.code === 200) {
                if (Number(res.data) === 0) {
                  setSettingMode("edit");
                } else {
                  setSettingMode("view");
                }
                setConfig(res1.data);
                setTrue();
              }
            });
        }
      });
    }
  };

  return (
    <div className={styles.container}>
      <Setting
        visible={showSettingModal}
        onClose={setFalse}
        mode={settingMode}
        initialValue={config}
      ></Setting>
      <div className={styles.contentWrapper}>
        <div className={styles.header}>
          <img
            src={composeImgUrl(applicationInfo?.icon ?? "")}
            alt=""
            style={{ width: 86, height: 86, borderRadius: 8 }}
          />
          <div>
            <div className={styles.itemTitle}>{applicationInfo?.thingName}</div>
            <Flex>
              <Space>
                <ArrowTag
                  text={applicationInfo?.thingType ? "行政许可" : "行政备案"}
                  style={{ color: "rgba(0, 119, 255, 1)" }}
                ></ArrowTag>
                <ArrowTag
                  text={applicationInfo?.implementingAgency}
                  color="#FFE0B7"
                  style={{
                    color: "rgba(255, 128, 3, 1)",
                  }}
                ></ArrowTag>
              </Space>
              <Space style={{ marginLeft: 24 }}>
                <IncludePopoverTag
                  title="设定依据"
                  content={applicationInfo?.legalBasis}
                ></IncludePopoverTag>
                <IncludePopoverTag
                  title="行使内容"
                  content={applicationInfo?.actionsTaken}
                ></IncludePopoverTag>
                <IncludePopoverTag
                  title="申请材料"
                  content={applicationInfo?.applicationMaterials}
                ></IncludePopoverTag>
                <IncludePopoverTag
                  title="办理流程"
                  content={applicationInfo?.specialProcedure}
                ></IncludePopoverTag>
              </Space>
            </Flex>
          </div>
          <div className={styles.action}>
            {isSuperAdmin && (
              <div className={styles.settingBtn} onClick={openSetting}>
                <SettingOutlined style={{ color: "#fff" }} />
              </div>
            )}

            <div
              className={styles.backBtn}
              onClick={() =>
                navigate("/management", {
                  replace: true,
                })
              }
            >
              <RollbackOutlined />
              返回
            </div>
          </div>
        </div>
        <div className={styles.tableWrapper}>
          <div className={styles.tableTitle}>事项申请记录</div>
          {applicationInfo && (
            <ListTable
              type={type ?? ""}
              applicationInfo={applicationInfo}
              active={active as string}
            ></ListTable>
          )}
        </div>
      </div>
    </div>
  );
};

export default PendingReviewList;
