import ReactECharts from 'echarts-for-react';
import { EChartsOption } from 'echarts'
import { CSSProperties, FC, useEffect, useRef, useState } from 'react';
import { Flex } from 'antd';
import styles from './PieChart.module.css'
import { merchantTypeStatisc } from '@/service/subjectDataVisual';


type propsType = {
    style: CSSProperties
}

const color = ['#1AE0B4', '#53ACFF']
const PieChart: FC<propsType> = (props) => {
    const { style, } = props
    const [option, setOption] = useState<EChartsOption>({})

    const [data, setData] = useState<any[]>([])
    const getData = async () => {
        const res = await merchantTypeStatisc()
        if (res.code === 200) {
            setData(res.data)
        }
    }
    useEffect(() => {
        getData()
    }, [])

    useEffect(() => {
        const option: EChartsOption = {
            tooltip: {
                show: true,
                trigger: 'item'
            },
            series: [
                {
                    name: '',
                    type: 'pie',
                    radius: ['0', '90%'],
                    center: 'center',
                    color,
                    data,
                    labelLine: { show: false },
                    label: { show: false },
                    emphasis: {
                        scaleSize: 5
                    }
                }
            ]
        }
        setOption(option)
        setTimeout(() => {
            echart.current?.getEchartsInstance().resize()
        })
    }, [data])
    const echart = useRef<ReactECharts>(null)

    return <Flex vertical style={style}>
        <div className={styles.title}>商户类别</div>
        <Flex flex={1} gap={45}>
            <ReactECharts
                ref={echart}
                style={{ height: '100%', width: 130 }}
                notMerge={true}
                lazyUpdate={true}
                option={option}
            />
            <Flex vertical justify='center' gap={10} flex={1}>
                {data.map((v, i) => {
                    const { value, name, percent } = v
                    return <Flex className={styles.item} key={i} justify='space-between'>
                        <Flex align='center' gap={10} className={styles.txt}><i style={{ background: color[i] }} />{name}</Flex>
                        <Flex gap={30} justify='space-between'>
                            <span className={styles.num}>{value}</span>
                            <span className={styles.num}>{percent} <span className={styles.unit}>%</span></span>
                        </Flex>
                    </Flex>
                })}
            </Flex>
        </Flex>
    </Flex>

}
export default PieChart