import { Button, Empty, message, notification } from "antd";
import styles from "./index.module.css";
import React, { useEffect, useLayoutEffect, useRef, useState } from "react";
import { useFormContext } from "..";
import ExamineNodeSetting from "./setting/examineNodeSetting";
import ApplyForNodeSetting from "./setting/applyForNodeSetting";
import TransactNodeSetting from "./setting/transactNodeSetting";

import service from "@/service";
import eventBus from "@/utils/eventBus";
import {
  NodeMap,
  buildElementParams,
  buildLineX6data,
  delPid,
  getDefaultNodeByType,
  replacePids,
} from "./util";
import { Graph, Edge, Node } from "@antv/x6";
import { useUpdateEffect } from "ahooks";
import { Portal, register } from "@antv/x6-react-shape";
import EndNodeRender from "./nodes/end";
import ActivityNode from "./nodes/activity";
import GatewayNode from "./nodes/gateway";
import { cloneDeep } from "lodash";
import { generateUUID } from "@/customForm/utils";
import { createRoot } from "react-dom/client";
import ConditionBtn from "./nodes/conditionBtn";
import ConditionNode from "./nodes/condition";
import ConditionNodeSetting from "./setting/conditionNodeSetting";
import ExamineOptionalNodeSetting from "./setting/examineOptionalNodeSetting";
import useGlobalData from "@/store/useGlobalData";
import X6ActionContext from "./X6ActionContext";

const X6ReactPortalProvider = Portal.getProvider();

register({
  shape: "custom-end-node",
  width: 297,
  height: 35,
  effect: ["data"],
  component: EndNodeRender,
});

register({
  shape: "custom-activity-node",
  width: 297,
  height: 108,
  effect: ["data"],

  component: ActivityNode,
});

register({
  shape: "custom-addCondition-node",
  width: 124,
  height: 64,
  component: ConditionBtn,
});

register({
  shape: "custom-condition-node",
  width: 297,
  height: 108,
  effect: ["data"],
  component: ConditionNode,
});
const Flow = () => {
  /** 当前操作对象 */
  const [actionNode, setActionNode] = useState<any>(getDefaultNodeByType(1));
  /** 流程图数据   */
  const { flowData, baseInfo, mode, flowMetaData } = useFormContext();
  const graphRef = useRef<Graph>();
  /** x6数据 */
  const [x6Data, setX6Data] = useState<{
    nodes: Node.Metadata[];
    edges: Edge.Metadata[];
  }>({
    nodes: [],
    edges: [],
  });

  /** 原始x6Data */
  const originalXNodesData = useRef<Node.Metadata[]>([
    {
      id: "startEvent",
      shape: "custom-activity-node",
      y: 0,
      data: {
        ...getDefaultNodeByType(1),
        pid: undefined,
      },
    },

    {
      id: "endEvent",
      shape: "custom-end-node",
      y: 300,
      data: {
        ...getDefaultNodeByType(),
        pid: "startEvent",
      },
    },
  ]);

  useEffect(() => {
    if (flowData && flowData.length > 0) {
      originalXNodesData.current = flowData;
      const startEvent = flowData.find((v: any) => v.id == "startEvent");

      setActionNode(startEvent?.data);
      renderGraph();
      /** 居中内容 */

      graphRef.current?.centerPoint(150, 200);
    }
  }, [flowData]);

  const { mainBodyTypes } = useGlobalData();

  const renderGraph = () => {
    const newX6Data = buildLineX6data(originalXNodesData.current);
    setX6Data(newX6Data);
  };

  const chartRef = useRef<HTMLDivElement>(null);

  /** 获取当前节点数据 */
  const getData = (id: string) => {
    return x6Data.nodes.find((item) => item.id === id)?.data;
  };

  /** 获取节点数据，打开弹窗  */
  const openSetting = (id: string) => {
    if (id === actionNode?.elementId) {
      setActionNode(undefined);
      return;
    }
    setActionNode(getData(id));
  };

  useUpdateEffect(() => {
    if (graphRef.current) {
      graphRef.current.fromJSON(x6Data);
    }
  }, [x6Data]);

  /** 初始化X6 */
  useLayoutEffect(() => {
    const graph = new Graph({
      container: chartRef.current!,
      background: {
        color: "#F2F7FA",
      },
      panning: true,
      interacting: {
        nodeMovable: false,
      },

      //@ts-ignore
      onEdgeLabelRendered: (args) => {
        console.log(args);
        const { selectors, edge } = args;
        const content = selectors.foContent as HTMLDivElement;

        if (content) {
          const root = createRoot(content);
          root.render(
            <GatewayNode edge={edge} graph={graph} addElement={addElement} />
          );
        }
      },
    });
    graphRef.current = graph;
    renderGraph();
    graph?.centerPoint(150, 200);
  }, []);

  const openNotification = (message: string) => {
    notification.open({
      message: message,
      description: "",
      type: "success",
      duration: 2,
    });
  };

  /** 新增元素 */
  const addElement = (
    type: string,
    edgeData: { target: Node.Metadata; source: Node.Metadata }
  ) => {
    if (type === "审批" || type === "办理") {
      addActivityElement(type, edgeData);
    }
    if (type === "街镇条件") {
      addConditionElement(edgeData);
    }
    if (type === "可选审批") {
      addOptionalNode(edgeData);
    }
  };

  /** 增加可选审批节点 */
  const addOptionalNode = (edgeData: {
    target: Node.Metadata;
    source: Node.Metadata;
  }) => {
    const { source, target } = edgeData;
    let cloneX6Data = cloneDeep(originalXNodesData.current);
    /** 第一步新增一个可选审批节点  */
    const nodeData = getDefaultNodeByType(5);
    const newNode = {
      id: nodeData.elementId,
      shape: "custom-activity-node",
      data: {
        ...nodeData,
        pid: source.id,
      },
    };

    /** 第二步 增加一条边to 下一节点 和一个审批节点 */
    const node1 = getDefaultNodeByType(3);
    const examineNode = {
      id: node1.elementId,
      shape: "custom-activity-node",
      data: {
        ...node1,
        pid: newNode.id,
        /** 条件为拟通过 */
        conditionId: newNode.id,
      },
    };
    cloneX6Data = cloneX6Data.map((v) => {
      if (v.id === target.id) {
        v.data.pid = v.data.pid?.replace(
          source.id as string,
          `${newNode.id},${examineNode.id}`
        );
      }
      return v;
    });

    originalXNodesData.current = [...cloneX6Data, newNode, examineNode];

    renderGraph();
  };

  /** 增加办理或者审批节点 */
  const addActivityElement = (
    type: string,
    edgeData: {
      target: Node.Metadata;
      source: Node.Metadata;
    }
  ) => {
    const nodeData = getDefaultNodeByType(type === "审批" ? 3 : 2);
    const { source, target } = edgeData;
    let cloneX6Data = cloneDeep(originalXNodesData.current);

    let newNode: any = {
      id: nodeData.elementId,
      shape: "custom-activity-node",
      data: {
        ...nodeData,
        pid: source.id,
      },
    };
    /** 在拟通过的条件节点上增加新的节点id，则默认需要加入条件id */
    if (source.data.conditionId) {
      newNode.data = { ...newNode.data, conditionId: source.data.conditionId };
    }
    cloneX6Data = cloneX6Data.map((v) => {
      if (v.id === target.id) {
        v.data.pid = v.data.pid?.replace(source.id as string, newNode.id);
      }
      return v;
    });
    originalXNodesData.current = [...cloneX6Data, newNode];

    renderGraph();
  };

  /** 增加条件节点 */
  const addConditionElement = (edgeData: {
    target: Node.Metadata;
    source: Node.Metadata;
  }) => {
    const { source, target } = edgeData;
    let cloneX6Data = cloneDeep(originalXNodesData.current);

    const nodeData = getDefaultNodeByType(4);

    const addCondition: Node.Metadata = {
      id: generateUUID(),
      shape: "custom-addCondition-node",
      data: {
        type: "addConditionBtn",
        pid: source.id,
      },
    };

    const conditionsNodeData = {
      id: generateUUID(),
      shape: "custom-condition-node",
      data: {
        conditionType: 0,
        nodeType: 4,
        pid: addCondition.id,
      },
    };

    const condition1: Node.Metadata = {
      id: nodeData.elementId,
      shape: "custom-condition-node",
      data: {
        ...nodeData,
        conditionType: 1,
        pid: addCondition.id,
      },
    };

    cloneX6Data = cloneX6Data.map((v) => {
      if (v.id === target.id) {
        v.data.pid = v.data.pid?.replace(source.id, conditionsNodeData.id);
      }
      if (v.id === "endEvent") {
        v.data.pid = v.data.pid + "," + condition1.id;
      }
      return v;
    });
    originalXNodesData.current = [
      ...cloneX6Data,
      addCondition,
      condition1,
      conditionsNodeData,
    ];
    /** 渲染 */
    renderGraph();
  };
  /** @description 更新 */
  const onUpdate = (params: any) => {
    for (const key in params) {
      actionNode[key] = params[key];
    }
    originalXNodesData.current = originalXNodesData.current.map((v) => {
      if (v.id === actionNode.elementId) {
        return {
          ...v,
          data: actionNode,
        };
      }
      return v;
    });

    renderGraph();
    openNotification("已更新节点信息");
  };

  const onSave = () => {
    const metaData =
      mode === "edit"
        ? {
            ...flowMetaData.current,
            originalData: JSON.stringify(originalXNodesData.current),
          }
        : {
            processId: baseInfo?.processId,
            processName: baseInfo?.thingName,
            description: "",
            originalData: JSON.stringify(originalXNodesData.current),
          };

    let ErrObj = {
      status: false,
      objName: "",
      noStreet: "",
      scopeStatus: false,
    };

    const nodeListByTranslate = originalXNodesData.current?.map((v) => {
      const temp = cloneDeep(v);

      const data = temp.data;
      if (data.nodeType === 3 || data.nodeType === 5) {
        data.forwardAndReverseName = (
          data.forwardAndReverseName as string[]
        )?.join(",");
      }

      if (data.nodeType === 4) {
        if (data.conditionType !== 0 && data.streetId === "") {
          ErrObj.noStreet = `街镇条件节点${data.conditionType}不能为空`;
        }
      }

      if (data.nodeType === 1) {
        const scopeKeys = data.scopeOfApplication?.split(",");
        console.log(data.scopeOfApplication);
        data.scopeCodeOfApplication = scopeKeys
          ?.map((keys: string) => {
            return mainBodyTypes.find((body) => body.id === keys)?.name;
          })
          .join(",");
        if (data.scopeOfApplication?.length == 0) {
          ErrObj.scopeStatus = true;
        }
      }

      if (data.nodeType === 3 || data.nodeType === 2 || data.nodeType === 5) {
        if (!data.approverList || data.approverList.length === 0) {
          ErrObj.status = true;
          ErrObj.objName = data?.elementAlias ?? "";
        }

        data.approverList = (data.approverList as unknown as string[])?.join(
          ","
        );
      }

      return temp;
    });

    /** 检验 */
    if (ErrObj.status) {
      message.warning(`${ErrObj.objName}节点缺少处理人员，请检查节点配置`);
      return;
    }

    if (ErrObj.noStreet && ErrObj.noStreet.length > 0) {
      message.warning(ErrObj.noStreet);
      return;
    }

    if (ErrObj.scopeStatus) {
      message.warning(`节点缺少申请范围，请检查节点配置`);
      return;
    }
    const ElementParams = buildElementParams(nodeListByTranslate);

    const params = {
      ...metaData,
      elementParams: ElementParams,
    };

    service.settingService.saveFlowConfig(params as any).then((res) => {
      if (res.code === 200) {
        openNotification(mode === "add" ? "创建成功" : "修改成功");
        eventBus.emit("updateList");
      }
    });
  };
  /** @description 增加条件节点 */
  const addCondition = (nodeId: string) => {
    const nodeData = getDefaultNodeByType(4);
    let cloneX6Data = cloneDeep(originalXNodesData.current);
    const childrenNum = cloneX6Data.filter(
      (v) => v.data.pid === nodeId
    )?.length;
    const condition: Node.Metadata = {
      id: nodeData.elementId,
      shape: "custom-condition-node",
      data: {
        ...nodeData,
        pid: nodeId,
        conditionType: childrenNum,
      },
    };
    cloneX6Data = cloneX6Data.map((v) => {
      if (v.id === "endEvent") {
        v.data.pid = v.data.pid + "," + condition.id;
      }
      return v;
    });
    originalXNodesData.current = [...cloneX6Data, condition];
    /** 渲染 */
    renderGraph();
  };
  /** @description 删除节点 */
  const onDelete = (nodeId: string) => {
    console.log("onDelete", nodeId);
    let cloneX6Data = cloneDeep(originalXNodesData.current);

    const nodeMap = NodeMap(cloneX6Data);
    const node = nodeMap.nodeMap.get(nodeId);
    const { pid, nodeType } = node.data;
    /** 如果删除的节点是选中节点，则清空选中节点 */
    if (actionNode?.elementId === nodeId) {
      setActionNode(undefined);
    }

    const deleteById = (id: string) => {
      if (id === "endEvent") {
        return;
      }
      const delNodePid = cloneX6Data.find((v) => v.id === id)?.data.pid;
      cloneX6Data = cloneX6Data.filter((v) => v.id !== id);
      const childNodes = nodeMap.childMap.get(id) ?? [];
      for (let childNode of childNodes) {
        let child = cloneX6Data.find((v) => v.id === childNode.id);
        child!.data.pid = replacePids(child!.data.pid, id, delNodePid);
      }
    };
    /** 不考虑替换id,彻底的链式删除 */
    const linksDelete = (id: string) => {
      if (id === "endEvent") {
        return;
      }
      cloneX6Data = cloneX6Data.filter((v) => v.id !== id);
      const childNodes = nodeMap.childMap.get(id) ?? [];
      for (let childNode of childNodes) {
        let child = cloneX6Data.find((v) => v.id === childNode.id);
        child!.data.pid = delPid(child!.data.pid, id);
        linksDelete(childNode.id);
      }
    };

    /** 删除审批节点 */
    if (nodeType === 2 || nodeType === 3) {
      deleteById(nodeId);
    }

    /** 删除条件 */
    if (nodeType === 4) {
      const childNodes = nodeMap.childMap.get(pid) ?? [];
      if (childNodes.length > 2) {
        linksDelete(nodeId);
      } else {
        // linksDelete(nodeId);
        deleteById(pid);

        for (let childNode of childNodes) {
          deleteById(childNode.id);
        }
        linksDelete(nodeId);
      }
    }
    /** 删除可选节点 */
    if (nodeType === 5) {
      /** 先删除本身节点 */
      deleteById(nodeId);
      /** 在删除全部的支线节点 */
      const childNodes = cloneX6Data.filter(
        (v) => v.data.conditionId === nodeId
      );
      cloneX6Data = cloneX6Data.filter((v) => v.data.conditionId !== nodeId);
      /** 移除剩余节点中，任意含有被删除节点的节点 */
      childNodes.forEach((childNode) => {
        cloneX6Data.forEach((v) => {
          if (v.data.pid?.includes(childNode.id)) {
            v.data.pid = delPid(v.data.pid, childNode.id!);
          }
        });
      });
    }

    originalXNodesData.current = cloneX6Data;
    renderGraph();
  };

  return (
    <div className={styles.container}>
      <X6ActionContext.Provider
        value={{
          addCondition,
          openSetting,
          actionNode,
          onDelete,
        }}
      >
        <X6ReactPortalProvider />
      </X6ActionContext.Provider>
      <div className={styles.contentWrapper}>
        <div
          className={styles.flowChartContent}
          id="flowChart"
          ref={chartRef}
        ></div>
        <div className={styles.settingContent}>
          {actionNode?.nodeType === 1 && (
            <ApplyForNodeSetting value={actionNode} onUpdate={onUpdate} />
          )}
          {actionNode?.nodeType === 2 && (
            <TransactNodeSetting value={actionNode} onUpdate={onUpdate} />
          )}
          {actionNode?.nodeType === 3 && (
            <ExamineNodeSetting value={actionNode} onUpdate={onUpdate} />
          )}
          {actionNode?.nodeType === 4 && (
            <ConditionNodeSetting value={actionNode} onUpdate={onUpdate} />
          )}
          {actionNode?.nodeType === 5 && (
            <ExamineOptionalNodeSetting
              value={actionNode}
              onUpdate={onUpdate}
            />
          )}
          {!actionNode && (
            <div style={{ textAlign: "center", marginTop: 100 }}>
              <Empty description="未选中任意流程节点"></Empty>
            </div>
          )}
        </div>
      </div>
      <div className={styles.footer}>
        <Button
          type="primary"
          disabled={mode === "view"}
          style={{ height: 50, fontSize: 18 }}
          onClick={onSave}
        >
          {mode === "add"
            ? "确定"
            : mode === "view"
            ? "需无办理中申请才能编辑配置"
            : "保存"}
        </Button>
      </div>
    </div>
  );
};

export default Flow;
