import { CloseOutlined, RightOutlined } from "@ant-design/icons";

import classNames from "classnames";
import styles from "./index.module.css";
import { Node } from "@antv/x6";

import { Button } from "antd";
import { useContext, useMemo } from "react";
import X6ActionContext from "../X6ActionContext";

type BaseNodeProps = {
  content: string;
  elementName: string;
  elementAlias: string;
  nodeType: 1 | 3 | 2 | 5;
  conditionId?: string;
};

const defConfig = {
  1: {
    headerBg: "#e1f2fd",
    decoratorBg: "#418af5",
    defTitle: "申请人",
    defContent: "请选择范围",
  },
  2: {
    headerBg: "#E6F8F8",
    decoratorBg: "#3DB4B2",
    defTitle: "办理节点",
    defContent: "请设置办理节点",
  },
  3: {
    headerBg: "#ead1a560",
    decoratorBg: "#f8a52a",
    defTitle: "审批节点",
    defContent: "请选择审批人",
  },
  5: {
    headerBg: "#ead1a5",
    decoratorBg: "#f8a52a",
    defTitle: "审批节点",
    defContent: "请选择审批人",
  },
};

/** 基础节点 */
const ActivityNode = ({ node }: { node: Node }) => {
  const { content, elementName, nodeType, elementAlias, conditionId } =
    node.getData<BaseNodeProps>();

  const { openSetting, actionNode, onDelete } = useContext(X6ActionContext);
  /** 是否选中 */
  const active = actionNode?.elementId === node.id;

  const showClose = useMemo(() => {
    if (nodeType === 1) {
      return false;
    }
    if (conditionId) {
      return false;
    }
    return true;
  }, [node]);
  return (
    <div className={styles.baseNode}>
      <div
        className={styles.decorator}
        style={{ backgroundColor: defConfig[nodeType]?.["decoratorBg"] }}
      ></div>

      <div
        className={styles.baseNodeHeader}
        style={{
          backgroundColor: defConfig[nodeType]["headerBg"],
          color: defConfig[nodeType]["decoratorBg"],
        }}
      >
        <div>
          {elementAlias ?? elementName ?? defConfig[nodeType]["defTitle"]}
        </div>
        {showClose && (
          <Button
            type="text"
            shape="circle"
            icon={<CloseOutlined />}
            onClick={onDelete?.bind(this, node.id)}
          ></Button>
        )}
      </div>
      <div
        className={classNames(styles.baseNodeContent, active && styles.active)}
        onClick={openSetting?.bind(this, node.id)}
      >
        <div>{content ?? defConfig[nodeType]["defContent"]}</div>
        <RightOutlined />
      </div>
    </div>
  );
};

export default ActivityNode;
