import { CloseOutlined, RightOutlined } from "@ant-design/icons";
import classNames from "classnames";
import styles from "./index.module.css";
import { Node } from "@antv/x6";

import { Button } from "antd";
import { useContext, useMemo } from "react";
import X6ActionContext from "../X6ActionContext";

type BaseNodeProps = {
  streetName?: string;
  elementName: string;
  elementAlias: string;
  nodeType: 1 | 3 | 4 | 5;
  conditionType?: number;
};

/** 基础节点 */
const ConditionNode = ({ node }: { node: Node }) => {
  const { streetName, conditionType } = node.getData<BaseNodeProps>();

  const { openSetting, actionNode, onDelete } = useContext(X6ActionContext);

  /** 是否选中 */
  const active = actionNode?.elementId === node.id;

  const showClose = useMemo(() => {
    if (conditionType === 0) {
      return false;
    }
    return true;
  }, [conditionType]);

  const getConditionTitle = () => {
    if (conditionType === 0) {
      return "默认条件";
    }

    return "条件" + conditionType;
  };

  const getConditionContent = () => {
    if (conditionType === 0) {
      return "未满足其他条件分支的情况，将使用默认流程";
    }
    return streetName ?? "请选择街道";
  };
  return (
    <div className={styles.baseNode}>
      <div
        className={styles.decorator}
        style={{ backgroundColor: "#7f8b98" }}
      ></div>

      <div
        className={styles.baseNodeHeader}
        style={{
          backgroundColor: "#EEF4FB",
          color: "#7f8b98",
        }}
      >
        <div>{getConditionTitle()}</div>

        {showClose && (
          <Button
            type="text"
            shape="circle"
            icon={<CloseOutlined />}
            onClick={onDelete?.bind(this, node.id)}
          ></Button>
        )}
      </div>
      <div
        className={classNames(styles.baseNodeContent, active && styles.active)}
        onClick={() => {
          if (conditionType) {
            openSetting?.(node.id);
          }
        }}
      >
        <div>{getConditionContent()}</div>
        <RightOutlined />
      </div>
    </div>
  );
};

export default ConditionNode;
