import { Button, Popover } from "antd";
import plus from "@/assets/images/setting/plus.png";
import styles from "./index.module.css";
import { Edge, Node } from "@antv/x6";
import { useBoolean } from "ahooks";
import { useEffect } from "react";

interface GatewayNodeProps {
  edge: Edge;
  addElement: (
    type: string,
    edgeData: { target: Node.Metadata; source: Node.Metadata }
  ) => void;
  graph: any;
}
/** 网管节点 */
const GatewayNode = (props: GatewayNodeProps) => {
  const { edge, addElement, graph } = props;
  const [open, { setFalse, setTrue }] = useBoolean(false);

  const edgeData = edge?.getData<{
    target: Node.Metadata;
    source: Node.Metadata;
  }>();

  /** 点击空白区域清除节点 */
  useEffect(() => {
    graph.on("blank:click", () => setFalse());
  }, []);
  return (
    <Popover
      placement="right"
      arrow={false}
      open={open}
      content={
        <div
          onClick={(e) => {
            e.stopPropagation();
            setFalse();
          }}
        >
          <Button type="text" onClick={() => addElement("办理", edgeData)}>
            办理
          </Button>
          <Button type="text" onClick={() => addElement("审批", edgeData)}>
            审批
          </Button>

          {edgeData.source.id === "startEvent" && (
            <Button
              type="text"
              onClick={() => addElement("街镇条件", edgeData)}
            >
              街镇条件
            </Button>
          )}

          {
            //降低复杂性，可选边上，不再嵌套可选
            !edgeData.source.data.conditionId && (
              <Button
                type="text"
                onClick={() => addElement("可选审批", edgeData)}
              >
                可选审批
              </Button>
            )
          }
        </div>
      }
    >
      <div className={styles.actionBtn} onClick={setTrue}>
        <img src={plus} alt="" style={{ width: 40, height: 40 }}></img>
      </div>
    </Popover>
  );
};

export default GatewayNode;
