import RenderComponent from "@/components/FormComponentRender/renderComponent";
import { ComponentsType } from "@/customForm/interfaces";
import { Button, Form } from "antd";
import FormSelect from "../components/formSelect";
import styles from "./applyForNodeSetting.module.css";
import { useEffect, useMemo } from "react";
import useGlobalData from "@/store/useGlobalData";

interface ApplyForNodeSettingProps {
  onUpdate: (value: any) => void;
  value: any;
}

const ApplyForNodeSetting = (props: ApplyForNodeSettingProps) => {
  const { onUpdate, value } = props;

  const { mainBodyTypes, initMainBodyTypes } = useGlobalData();
  useEffect(() => {
    initMainBodyTypes();
  }, []);

  useEffect(() => {
    form.setFieldsValue(value);
  }, [value]);
  const FormConfig = useMemo(() => {
    const options = mainBodyTypes?.map((v: any) => {
      return {
        label: v.name,
        value: v.id,
      };
    });

    return [
      {
        label: "申请范围",
        componentType: "Checkbox",
        key: "scopeOfApplication",
        config: {
          options: options ?? [],
        },
      },
      {
        label: "申请内容",
        //@ts-ignore
        component: <FormSelect />,
        key: "examineKeys",
      },
    ];
  }, [mainBodyTypes]);
  const [form] = Form.useForm();

  const onFinish = (values: any) => {
    onUpdate(values);
  };
  return (
    <div className={styles.container}>
      <div className={styles.content}>
        <div className={styles.title}>设置申请范围</div>
        <Form
          form={form}
          colon={false}
          layout="vertical"
          onFinish={onFinish}
          // onChange={}
        >
          {FormConfig.map((item) => {
            return (
              <Form.Item key={item.key} label={item.label} name={item.key}>
                {item.component ? (
                  item.component
                ) : (
                  <RenderComponent
                    config={item.config}
                    componentType={item.componentType as ComponentsType}
                  ></RenderComponent>
                )}
              </Form.Item>
            );
          })}
          <Form.Item>
            <Button type="primary" htmlType="submit">
              保存
            </Button>
          </Form.Item>
        </Form>
      </div>
    </div>
  );
};

export default ApplyForNodeSetting;
