import RenderComponent from "@/components/FormComponentRender/renderComponent";
import { ComponentsType } from "@/customForm/interfaces";
import { Button, Form } from "antd";
import styles from "./examineNodeSetting.module.css";
import { useEffect, useMemo, useState } from "react";
import service from "@/service";

interface ExamineNodeSettingProps {
  onUpdate: (value: any) => void;
  value: any;
}
const ConditionNodeSetting = (props: ExamineNodeSettingProps) => {
  const { onUpdate, value } = props;
  const [streetList, setStreetList] = useState<any[]>([]);

  const FormConfig = useMemo(() => {
    return [
      {
        label: "选择街镇",
        componentType: "Select",
        key: "streetId",

        config: {
          placeholder: "请输入",
          size: "large",
          option: streetList,
        },
      },
    ];
  }, [streetList]);
  const [form] = Form.useForm();

  useEffect(() => {
    service.commonService.getAllStreet().then((res) => {
      if (res.code === 200) {
        const config = res.data.map((v) => {
          return { ...v, value: v.code, label: v.name };
        });

        setStreetList(config);
      }
    });
  }, []);
  useEffect(() => {
    if (value) {
      form.setFieldsValue(value);
    }
  }, [value]);
  const onFinish = (values: any) => {
    console.log(values);
    const { streetId } = values;
    const streetName = streetList.find((v) => v.value === streetId)?.label;
    onUpdate({ streetName, ...values });
  };
  return (
    <div className={styles.container}>
      <div className={styles.content}>
        <div className={styles.title}>添加条件节点</div>
        <Form form={form} colon={false} layout="vertical" onFinish={onFinish}>
          {FormConfig.map((item) => {
            return (
              <Form.Item
                label={item.label}
                name={item.key}
                required={false}
                key={item.key}
                rules={[
                  {
                    required: true,
                    message: `请设置${item?.label}`,
                  },
                ]}
              >
                <RenderComponent
                  config={item.config}
                  componentType={item.componentType as ComponentsType}
                ></RenderComponent>
              </Form.Item>
            );
          })}
          <Form.Item>
            <Button type="primary" htmlType="submit">
              保存
            </Button>
          </Form.Item>
        </Form>
      </div>
    </div>
  );
};

export default ConditionNodeSetting;
