import { generateUUID } from "@/customForm/utils";

import { Markup, type Edge, type Node } from "@antv/x6";
import { cloneDeep } from "lodash";

function clearNodes(nodes: Node.Metadata[]) {
  const tempNode = cloneDeep(nodes);

  /** 移除无用的节点 */
  const addConditionBtnNodes = tempNode.filter((node) => {
    return node.data?.type === "addConditionBtn";
  });

  const withoutBtnNodes = tempNode.filter((node) => {
    return node.data?.type !== "addConditionBtn";
  });
  withoutBtnNodes.forEach((node) => {
    const pBtn = addConditionBtnNodes.find((btn) => {
      return btn.id === node.data.pid;
    });
    if (pBtn) {
      node.data.pid = pBtn.data.pid;
    }
  });
  const { childMap } = NodeMap(withoutBtnNodes);
  const conditionTypeNodes = withoutBtnNodes.filter((node) => {
    return node.data?.nodeType === 4;
  });

  const withoutConditionTypeNodes = withoutBtnNodes.filter((node) => {
    return node.data?.nodeType !== 4;
  });

  withoutConditionTypeNodes.forEach((node) => {
    const pBtn = conditionTypeNodes.find((btn) => {
      const pids = node.data.pid?.split(",") ?? [];
      return pids.includes(btn.id);
    });
    if (pBtn) {
      node.data.pid = replacePids(node.data.pid, pBtn.id!, pBtn.data.pid);
      if (pBtn.data.conditionType === 0) {
        const allChild = childMap.get(pBtn.data.pid!);
        const streetIds =
          allChild?.map((v) => v.data?.streetId).filter((v) => v) ?? [];
        // debugger;
        const str = streetIds.reduce((pre, cur, index) => {
          console.log(index, streetIds);
          if (index === 0) {
            if (streetIds.length == 1) {
              return "${" + "streetId!='" + cur + "'}";
            }
            return "${" + "streetId!='" + cur + "'";
          }
          if (index === streetIds.length - 1) {
            return pre + "&&" + "streetId!='" + cur + "'}";
          }
          return pre + "&&" + "streetId!='" + cur + "'";
        }, "");

        node.data = {
          ...node.data,
          conditionExpression: str,
        };
      } else {
        node.data = {
          ...node.data,
          conditionExpression: "${streetId=='" + pBtn.data.streetId + "'}",
        };
      }
    }
  });

  return withoutConditionTypeNodes;
}

export function buildElementParams(nodes: Node.Metadata[]) {
  let newResult = [] as any[];
  const newNodes = clearNodes(nodes);
  console.log(newNodes, nodes);
  const { childMap } = NodeMap(newNodes);
  const createEdgeAndNode = (node: Node.Metadata, child: Node.Metadata) => {
    const childData = child.data;
    const nodeData = node.data;
    /** 条件节点 */
    let edges: any[] = [
      {
        elementId: generateUUID(),
        elementName: "连接线",
        elementType: 3,
        from: node.id,
        to: child.id,
      },
    ];
    /** 父节点为条件节点 */
    if (childData.conditionExpression) {
      edges[0] = {
        ...edges[0],
        conditionType: 1,
        conditionExpression: childData.conditionExpression,
      };
    }
    /** 父节点为条件节点 */
    if (nodeData.nodeType === 3 || nodeData.nodeType === 5) {
      edges[0] = {
        ...edges[0],
        conditionType: 2,
        approveResult: 2, //固定
      };
    }

    /** 父节点为拟通过节点 */
    if (childData.conditionId) {
      edges[0] = {
        ...edges[0],
        conditionType: 2,
        approveResult: 4, //固定
      };
    }

    /** 当前节点为审批节点 */
    if (childData.nodeType === 3 || childData.nodeType === 5) {
      edges.push({
        approveResult: 3, //固定
        conditionType: 2, //固定
        elementId: generateUUID(), //随机生成
        elementName: "连接线",
        elementType: 3,
        from: child.id, //来源节点
        to: "endEvent", //目标节点
      });
    }

    newResult.push(...edges);
  };

  newNodes.forEach((node) => {
    const children = childMap.get(node.id!) || [];
    console.log(children);
    children.forEach((child) => {
      createEdgeAndNode(node, child);
    });
  });

  /** 加入申请节点 */
  const init = [
    {
      elementId: generateUUID(),
      elementName: "开始连接线",
      elementType: 3,
      from: "start",
      to: "startEvent",
    },
    {
      elementId: "start",
      elementName: "开始节点",
      elementType: 1,
    },
    ...newNodes.map((v) => v.data),
  ];
  newResult.push(...init);

  return newResult;
}

const nodeWidthMapping = {
  "custom-end-node": 297,
  "custom-activity-node": 297,
  "custom-gateWay-node": 40,
  "custom-addCondition-node": 124,
  "custom-condition-node": 297,
};

export function NodeMap(nodes: Node.Metadata[]) {
  const nodeMap = new Map<string, any>();
  nodes.forEach((node) => {
    nodeMap.set(node.id!, node);
  });

  // 建立每个节点的子节点映射
  const childMap = new Map<string, any[]>();
  nodes.forEach((node) => {
    const pids = (node.data.pid || "")
      .split(",")
      .map((pid: string) => pid.trim());

    pids.forEach((pid: string) => {
      if (pid) {
        if (!childMap.has(pid)) {
          childMap.set(pid, []);
        }
        childMap.get(pid)?.push(node);
      }
    });
  });
  return {
    nodeMap,
    childMap,
  };
}

/**
 * 构建线数据
 * 根据节点 pid 管理，从根节点开始更新每个节点的 y 和 x 值
 * 节点呈金字塔形排布，每个父子节点之间插入一个网关节点
 */
export function buildLineX6data(nodes: Node.Metadata[]): {
  nodes: Node.Metadata[];
  edges: Edge.Metadata[];
} {
  // 建立一个节点的映射，方便通过 id 快速查找节点

  const { childMap } = NodeMap(nodes);

  const edges: Edge.Metadata[] = [];
  let maxLevel = 0;

  // 递归更新每个节点的 x 和 y 值
  const updatePosition = (node: any, level: number, baseX: number) => {
    // 设置 y 值，y 值为每层级相差 300
    node.y = level * 200;
    // console.log(node);
    // 获取子节点，并计算它们的总宽度
    let children = childMap.get(node.id) || [];
    if (children.length === 0) {
      return;
    }
    const nodeW = nodeWidthMapping[node.shape as keyof typeof nodeWidthMapping];
    const totalWidth = children.reduce((pre, cur, index) => {
      const w = nodeWidthMapping[cur.shape as keyof typeof nodeWidthMapping];
      return pre + w + (index > 0 ? 100 : 0);
    }, 0); // 子节点总宽度
    // 基于父节点的 x 值，将子节点居中排列
    const startX = baseX + nodeW / 2 - totalWidth / 2; // 从居中的位置开始
    if (level > maxLevel) {
      maxLevel = level;
    }

    /** 排序子节点，如果字节点中存在父节点是审批节点的情况,考虑children最多存在两个，永远将审批节点右置 */
    children = children.sort((a) => {
      return a.data.conditionId ? 1 : -1;
    });

    children.forEach((child, index) => {
      // 每个子节点的 x 值基于父节点的 x，并均匀排布
      const w = nodeWidthMapping[child.shape as keyof typeof nodeWidthMapping];

      child.x = startX + index * (w + 100);
      updatePosition(child, level + 1, child.x); // 递归更新子节点的位置
    });
  };

  // 初始化根节点（没有 pid 的节点）
  nodes.forEach((node) => {
    if (!node.data.pid) {
      node.x = 0; // 根节点 x 从 0 开始，居中
      updatePosition(node, 0, node.x); // 从根节点开始递归更新位置
    }
  });
  console.log(nodes);
  // debugger;
  const findEndNodes = () => {
    return nodes.find((v) => v.id === "endEvent");
  };
  /** 重置结束事件的位置,一定位于层级最底层 */
  const resetEndNode = () => {
    const node = findEndNodes();
    node!.y = maxLevel * 200 + 200;
    node!.x = 0;
  };

  resetEndNode();

  const createEdge = (node: Node.Metadata, child: Node.Metadata) => {
    if (node.data?.type === "addConditionBtn") {
      edges.push({
        source: node.id,
        target: child.id,
        router: {
          name: "manhattan",
          args: {
            startDirections: ["left", "right"],
            endDirections: ["top"],
          },
        },
        attrs: {
          line: {
            stroke: "#ccc",
          },
        },
      });
      return;
    }
    if (child.data?.conditionId) {
      const labelText = node.data?.forwardAndReverseName[0];
      edges.push({
        source: node.id,
        target: child.id,
        router: {
          name: "manhattan",
          args: {
            startDirections: ["right"],
            endDirections: ["right"],
          },
        },
        label: {
          markup: [
            {
              tagName: "rect",
              selector: "labelBody",
            },
            {
              tagName: "text",
              selector: "labelText",
            },
          ],
          attrs: {
            labelText: {
              text: labelText,
              fill: "#ffa940",
              textAnchor: "middle",
              textVerticalAnchor: "middle",
            },
            labelBody: {
              ref: "labelText",
              refX: -8,
              refY: -5,
              refWidth: "100%",
              refHeight: "100%",
              refWidth2: 16,
              refHeight2: 10,
              stroke: "#ffa940",
              fill: "#fff",
              strokeWidth: 2,
              rx: 5,
              ry: 5,
            },
          },
          position: {
            distance: 0.3,
            args: {
              keepGradient: true,
              ensureLegibility: true,
            },
          },
        },
        // label: "拟通过",
        attrs: {
          line: {
            stroke: "#ccc",
          },
        },
      });
      return;
    }
    edges.push({
      source: node.id,
      target: child.id,
      router: {
        name: "manhattan",
        args: {
          startDirections: ["bottom"],
          endDirections: ["top"],
        },
      },
      defaultLabel: {
        markup: Markup.getForeignObjectMarkup(),
        attrs: {
          fo: {
            width: 40,
            height: 40,
            x: -20,
            y: -20,
          },
        },
      },
      label: {
        position: 0.35,
      },
      data: { source: node, target: child },
      attrs: {
        line: {
          stroke: "#ccc",
        },
      },
    });
  };
  // 重新计算网关节点的位置

  nodes.forEach((node) => {
    const children = childMap.get(node.id!) || [];
    children.forEach((child) => {
      createEdge(node, child);
    });
  });

  // 合并原始节点和网关节点
  const allNodes = [...nodes];
  return { nodes: allNodes, edges };
}

export function addPids(pid: string, newP: string) {
  const pids = (pid || "").split(",").map((pid: string) => pid.trim());
  if (pids.includes(newP)) {
    return pid;
  }
  pids.push(newP);
  return pids.join(",");
}

export function delPid(pid: string, delP: string) {
  const pids = (pid || "").split(",").map((pid: string) => pid.trim());
  if (!pids.includes(delP)) {
    return pid;
  }
  return pids.filter((pid) => pid !== delP).join(",");
}

export function replacePids(pid: string, oldP: string, newP: string) {
  const pids = (pid || "").split(",").map((pid: string) => pid.trim());

  if (!pids.includes(newP)) {
    return [...new Set(pids.map((pid) => (pid === oldP ? newP : pid)))].join(
      ","
    );
  }
  return pid;
}

/** 新增节点 */
export function getDefaultNodeByType(type?: 1 | 2 | 3 | 4 | 5) {
  switch (type) {
    case 1:
      return {
        elementId: "startEvent",
        elementName: "申请人",
        nodeType: 1,
        /** 处理内容 */
        examineKeys: "all",
        assigneeKey: "applicant",
        elementType: 2,
        scopeOfApplication: "",
        elementAlias: "申请人",
        signType: 3,
      };
    case 2:
      return {
        elementId: generateUUID(),
        elementName: "办理节点",
        elementAlias: "办理节点",
        approverList: [],
        elementType: 2,
        icon: "",
        enableSelectNextNodeUser: false,
        assigneeKey: "_approver_",
        approverType: 1,
        signType: 3,
        examineKeys: "all",
        nodeType: 2,
      };

    case 3:
      return {
        elementId: generateUUID(),
        elementName: "审批节点",
        elementAlias: "审批节点",
        enableSelectNextNodeUser: false,
        approverType: 1,
        nodeType: 3,
        signType: 3,
        icon: "",
        assigneeKey: "_approver_",
        elementType: 2,
        approverList: [],
        forwardAndReverseName: ["同意", "驳回"],
        examineKeys: "all",
      };
    case 4:
      return {
        elementId: generateUUID(),
        /** 街道id */
        streetId: "",
        nodeType: 4,
        elementType: 2,
      };
    case 5: {
      return {
        elementId: generateUUID(),
        elementName: "可选审批节点",
        elementAlias: "可选审批节点",
        approverType: 1,
        nodeType: 5,
        enableSelectNextNodeUser: false,
        signType: 3,
        icon: "",
        assigneeKey: "_approver_",
        elementType: 2,
        approverList: [],
        forwardAndReverseName: ["领导审批", "同意", "驳回"],
        examineKeys: "all",
      };
    }

    default:
      return {
        elementId: "endEvent",
        elementName: "结束节点",
        elementType: 4,
        nodeType: 6,
      };
  }
}
