import type { FormComponentRegistryInfo } from "@/customForm/interfaces";
import styles from "./menu.module.css";
import { Components } from "@/customForm/registry";
import BaseFormComponent from "@/customForm/entity/base";
import { useFormContext } from "..";
import eventBus from "@/utils/eventBus";

/**
 * tools
 */
const Menu = (props: { groupId?: string; onClick?: () => void }) => {
  let menuList = Components.meta.filter(
    (item) => item.componentType !== "Select"
  );
  const { formConfigList, setFormConfigList } = useFormContext();
  const { groupId, onClick } = props;

  const clickHandler = (params: FormComponentRegistryInfo) => {
    const key = params.componentType;
    if (key) {
      const componentConstruct = Components.get(
        key
      ) as typeof BaseFormComponent;
      const newItem = new componentConstruct();
      /** 分组显示 */
      if (groupId) {
        /**
         *
         * 往分组中插入子项
         */
        newItem.setValues({
          groupId,
        });
        const group = formConfigList.find((v) => v.key === groupId);
        group?.componentOption?.addChild(newItem);
        /** 主动触发一次更新 */
        setFormConfigList([...formConfigList]);
      } else {
        /** 更新默认选中 */
        setFormConfigList([...formConfigList, newItem]);
      }
      eventBus.emit("add-form-item", newItem);
    } else throw new Error("key is undefined");
    if (onClick) onClick();
  };

  if (groupId) {
    menuList = menuList.filter((v) => v.componentType !== "Branch");
  }

  return (
    <div className={styles.container}>
      {menuList.map((item, index) => {
        return (
          <div
            key={index}
            className={styles.menuItem}
            onClick={(e) => {
              e.stopPropagation();
              clickHandler(item);
            }}
          >
            <div className={styles.btnContent}>
              <div>
                <img
                  src={item.icon}
                  alt=""
                  style={{ width: 21, height: 21 }}
                ></img>
              </div>
              {item.name}
            </div>
          </div>
        );
      })}
    </div>
  );
};

export default Menu;
