import type { OnlyProperties } from "@/customForm/interfaces";
import styles from "./basic.module.css";
import { Button, Form, notification } from "antd";
import RenderComponent from "../../components/FormComponentRender/renderComponent";
import BaseFormComponent from "@/customForm/entity/base";
import { buildListByGroupId, generateUUID } from "@/customForm/utils";
import { submitBaseSetting } from "@/service/settingController";

import { useFormContext } from ".";
import { useEffect } from "react";
import { useUpdateEffect } from "ahooks";
const formConfig: OnlyProperties<BaseFormComponent>[] = [
  {
    label: "事项名称",
    componentType: "TextInput",
    key: "thingName",
    groupId: "1",
    validationRules: [],
    componentOption: {
      require: true,
      placeholder: "输入事项名称",
    },
  },
  {
    label: "事项图标/插画",
    componentType: "ImgUpload",
    key: "icon",
    groupId: "1",
    validationRules: [],
    componentOption: {
      require: false,
      placeholder: "上传事项图标",
    },
  },

  {
    label: "实施机构",
    componentType: "TextInput",
    key: "implementingAgency",
    groupId: "2",
    validationRules: [],
    componentOption: {
      require: true,

      placeholder: "输入机构名称",
    },
  },
  {
    label: "事项类型",
    componentType: "Radio",
    key: "thingType",
    groupId: "1",
    validationRules: [],

    componentOption: {
      require: true,

      option: [
        {
          label: "行政备案",
          value: 0,
        },
        {
          label: "行政许可",
          value: 1,
        },
      ],
    },
  },
  {
    label: "实施主体性质",
    componentType: "Select",
    key: "agencyType",
    groupId: "2",
    validationRules: [],

    componentOption: {
      options: [
        {
          label: "自然人",
          value: "自然人",
        },
        {
          label: "企业",
          value: "企业",
        },
        {
          label: "个体工商户",
          value: "个体工商户",
        },
      ],
      require: true,

      style: {
        width: "100%",
      },
    },
  },
  {
    label: "行使层级",
    componentType: "Select",
    key: "thingLevel",
    groupId: "1",
    validationRules: [],

    componentOption: {
      require: true,

      options: [
        {
          label: "国家级",
          value: "国家级",
        },
        {
          label: "省级",
          value: "省级",
        },
        {
          label: "市级",
          value: "市级",
        },
        {
          label: "区级",
          value: "区级",
        },
      ],
      style: {
        width: "100%",
      },
    },
  },
  {
    label: "法定办结时限",
    componentType: "TextInput",
    key: "statutoryCompletionDeadline",
    groupId: "2",
    validationRules: [
      {
        min: 0,
        transform(value) {
          return Number(value);
        },
        message: "承诺办结时限必须大于0",
      },
    ],
    componentOption: {
      placeholder: "输入日期",
      type: "number",
      require: true,

      suffix: "个工作日",
      style: {
        width: "100%",
      },
    },
  },
  {
    label: "权限划分",
    componentType: "TextInput",
    key: "authorityDivision",
    groupId: "1",
    validationRules: [],

    componentOption: {
      placeholder: "输入权限划分",
      require: true,
    },
  },
  {
    label: "承诺办结时限",
    componentType: "TextInput",
    key: "promisedCompletionDeadline",
    groupId: "2",
    validationRules: [
      {
        min: 0,
        message: "承诺办结时限必须大于0",
        transform(value) {
          return Number(value);
        },
      },
    ],

    componentOption: {
      placeholder: "输入日期",
      type: "number",
      suffix: "个工作日",
      require: true,
      style: {
        width: "100%",
      },
    },
  },
  {
    label: "设定依据",
    componentType: "TextAreaInput",
    key: "legalBasis",
    groupId: "1",
    validationRules: [],

    componentOption: {
      placeholder: "输入事项设定依据",
      rows: 4,

      require: true,
    },
  },
  {
    label: "特别程序",
    componentType: "TextInput",
    key: "specialProcedure",
    validationRules: [],

    groupId: "2",
    componentOption: {
      placeholder: "无",
      require: true,
    },
  },
  {
    label: "受理条件",
    componentType: "TextAreaInput",
    key: "acceptanceCriteria",
    groupId: "2",
    validationRules: [],

    componentOption: {
      placeholder: "输入受理条件",
      rows: 3,
      require: true,
    },
  },
  {
    label: "行使内容",
    componentType: "TextAreaInput",
    key: "actionsTaken",
    groupId: "1",
    validationRules: [],

    componentOption: {
      placeholder: "输入内容",
      rows: 4,

      require: true,
    },
  },
  {
    label: "申请材料",
    componentType: "TextAreaInput",
    key: "applicationMaterials",
    groupId: "2",
    validationRules: [],

    componentOption: {
      placeholder: "输入内容",
      rows: 4,

      require: true,
    },
  },
  {
    label: "分组名称",
    componentType: "TextInput",
    key: "groupName",
    groupId: "1",
    validationRules: [],

    componentOption: {
      placeholder: "输入分组名称",
      require: false,
    },
  },
  {
    label: "分组描述",
    componentType: "TextAreaInput",
    key: "groupDesc",
    groupId: "2",
    validationRules: [],
    componentOption: {
      placeholder: "输入内容",
      rows: 4,
      require: false,
    },
  },
  {
    label: "用户指南",
    componentType: 'FileUpload',
    key: "handlingGuideAnnex",
    groupId: "1",
    validationRules: [],
    componentOption: {
      require: false,
      placeholder: "请上传用户指南pdf"
    },
  },
];

const groupIdConfig = buildListByGroupId(formConfig as BaseFormComponent[]);

const Basic = () => {
  const [form] = Form.useForm();

  const { baseInfo, setBaseInfo, mode, setActiveKey, setActiveTabs } =
    useFormContext();

  useEffect(() => {
    if (mode === "add") {
      const temp = {
        matterCode: generateUUID(),
        processId: generateUUID(),
      };
      setBaseInfo(temp);
    }
  }, []);

  useUpdateEffect(() => {
    form.setFieldsValue(baseInfo);
  }, [baseInfo]);

  const onFinish = (values: any) => {
    const params = {
      ...baseInfo,
      ...values,
      groupName: values.groupName ?? values.thingName,
    };

    submitBaseSetting(params).then((res) => {
      if (res.code === 200) {
        setBaseInfo({
          ...params,
          id: res.data,
        });
        if (mode === "add") {
          setActiveTabs(["1", "2"]);
          setActiveKey("2");
        } else {
          notification.success({
            message: "修改成功",
            duration: 1.5,
          });
        }
      }
    });
  };

  return (
    <div className={styles.container}>
      <Form
        layout="inline"
        form={form}
        colon={false}
        style={{ maxWidth: "none" }}
        labelCol={{ span: 6 }}
        wrapperCol={{ span: 18 }}
        onFinish={onFinish}
        initialValues={baseInfo}
        requiredMark={false}
      >
        {groupIdConfig.map((groupIdItem) => {
          return (
            <div className={styles.itemWrapper} key={groupIdItem.title}>
              {groupIdItem.list.map((formItem) => {
                return (
                  <Form.Item
                    label={formItem.label}
                    name={formItem.key}
                    key={formItem.key}
                    className={styles.formItem}
                    rules={[
                      {
                        required: formItem.componentOption?.require,
                        message: `请填写${formItem?.label}`,
                      },
                      ...formItem.validationRules,
                    ]}
                  >
                    <RenderComponent
                      config={formItem.componentOption}
                      componentType={formItem.componentType}
                    ></RenderComponent>
                  </Form.Item>
                );
              })}
            </div>
          );
        })}
      </Form>
      <div style={{ float: "right" }}>
        <Button
          type="primary"
          onClick={form.submit}
          disabled={mode === "view"}
          style={{ height: 50, fontSize: 18 }}
        >
          {mode === "add"
            ? "下一步"
            : mode === "view"
            ? "需无办理中申请才能编辑配置"
            : "保存"}
        </Button>
      </div>
    </div>
  );
};

export default Basic;
