import { Button, Flex } from "antd";

import icon1 from "@/assets/images/applyRecord/shengpi.png";
import styles from "./progress-item.module.css";

import {
  CheckOutlined,
  HourglassOutlined,
  SnippetsOutlined,
  StopOutlined,
} from "@ant-design/icons";
import classNames from "classnames";

interface ProgressItemProps {
  progressData: any;
  onClick: () => void;
}

const ProgressItem: React.FC<ProgressItemProps> = (props) => {
  const { progressData = {}, onClick } = props;
  const approveHistories = progressData?.approveHistories ?? [];

  // const failMessage = progressData.find((v) => v?.status === 1)?.remark;
  const getCurClass = (params: any) => {
    if (params.current) {
      return styles.curActive;
    }
    if (params.approveStatus !== undefined && !params.approveStatus) {
      return styles.fail;
    }
    if (params.approveTime) {
      return styles.passStatus;
    }
    return styles.unPassStatus;
  };

  const getCurIcon = (params: any) => {
    if (params.current) {
      return <HourglassOutlined style={{ fontSize: 18 }} />;
    }
    if (params.approveStatus !== undefined && !params.approveStatus) {
      return <StopOutlined style={{ fontSize: 18 }} />;
    }

    if (params.approveTime) {
      return (
        <div className={styles.okIcon}>
          <CheckOutlined style={{ color: "#fff" }} />
        </div>
      );
    }
    return <SnippetsOutlined style={{ fontSize: 18 }} />;
  };

  const failMessage = approveHistories.find((item: any) => {
    return item?.approveStatus !== undefined && !item?.approveStatus;
  })?.approveComment;
  return (
    <div className={styles.container}>
      <Flex align="center" justify="space-between">
        <Flex gap={12}>
          <div className={styles.tag}>
            <img alt="" src={icon1} style={{ width: 15, height: 15 }}></img>
            <div>{progressData?.caseStatus.name}</div>
          </div>
          <div className={styles.title}>
            {progressData.createAt}申请的{progressData?.name}
          </div>
        </Flex>
        <Button type="primary" shape="round" onClick={onClick}>
          查看
        </Button>
      </Flex>

      <div className={styles.progressBar}>
        {approveHistories.map((item: any, i: number) => {
          return (
            <div
              key={item.nodeCode}
              className={classNames(styles.progressCardItem, getCurClass(item))}
              style={{ zIndex: 100 - i, transform: `translateX(${-48 * i}px)` }}
            >
              {getCurIcon(item)}
              <div>
                <div className={styles.nodeTitle}>{item.nodeName}</div>
                <div>{item?.approveTime}</div>
              </div>
            </div>
          );
        })}
      </div>

      {failMessage && <div className={styles.remark}>备注：{failMessage}</div>}
    </div>
  );
};

export default ProgressItem;
