import BasicModal from "@/components/BasicModal";
import styles from "./index.module.css";
import applyIcon from "@/assets/images/form/apply.png";
import { Button, Form, message } from "antd";

import { inversionSerializationRule } from "@/customForm/utils";
import RenderComponent from "../../../components/FormComponentRender/renderComponent";

import { useEffect, useMemo, useState } from "react";
import { useModalConfigContext } from "../Main";
import service from "@/service";
import useUserStore from "@/store/useUserStore";
import { useLockFn } from "ahooks";

const SubmitApplication = () => {
  const [form] = Form.useForm();
  const { modalOption, setModalOption } = useModalConfigContext();
  const [visible, setVisible] = useState(false);
  const [dataSource, setDataSource] = useState<any>({});
  const { userInfo } = useUserStore();
  const { mainBodyInfo } = useUserStore();
  const [applicationConfig, setApplicationConfig] = useState<any>();

  const formConfig = useMemo(() => {
    const matterContentList = dataSource?.matterContentList;

    if (matterContentList && applicationConfig?.examineKeys) {
      let temp = matterContentList
        .sort((pre: any, cur: any) => pre.sort - cur.sort)
        .map((item: any) => {
          return {
            ...item,
            componentOption: item.otherSet ? JSON.parse(item.otherSet) : {},
            key: item.fieldKey,
            validationRules: inversionSerializationRule(item.validationRules),
          };
        });
      /** 过滤需要处理的内容 */
      if (applicationConfig?.examineKeys !== "all") {
        const keys = applicationConfig?.examineKeys?.split(",") ?? [];
        temp = temp.filter((item: any) => keys.includes(item.fieldKey));
      }

      return temp;
    }
    return [];
  }, [dataSource, applicationConfig]);

  useEffect(() => {
    if (modalOption.show) {
      setVisible(true);
    } else {
      form.resetFields();
      setVisible(false);
    }
  }, [modalOption]);

  useEffect(() => {
    const id = modalOption.metaData?.id;
    if (id) {
      service.settingService.getTemplateConfig(id).then((res) => {
        if (res.code === 200) {
          setDataSource(res.data);
          service.applyService
            .getApplicationNodeConfig(res.data.flowProcessId)
            .then((res1) => {
              if (res1.code === 200) {
                setApplicationConfig(res1.data);
              }
            });
        }
      });
    }
  }, [modalOption.metaData]);

  const onSubmit = () => {
    form.submit();
  };

  const closeHandler = () => {
    setVisible(false);
    setModalOption({ show: false, metaData: {} });
  };
  const onFinish = useLockFn(async (data: any) => {
    const mainBody = mainBodyInfo?.[0];

    const metaData = {
      thingId: modalOption.metaData.id,
      name: modalOption.metaData.thingName,
      loginName: userInfo.username,
      applicantType: "自然人",
      remake: "",
      subjectName: mainBody?.name,
      subjectCode: mainBody?.unifiedSocialCreditCode,
      subjectAddress: mainBody?.address,
      subjectContact: mainBody?.contactName,
      subjectPhone: mainBody?.phone,
      subjectStreet: mainBody?.streetCode,
    };
    let forms = [];
    const matterContentList = dataSource?.matterContentList;

    for (const key in data) {
      const itemConfig = matterContentList.find((v: any) => v.fieldKey === key);
      if (itemConfig) {
        forms.push({
          reportName: userInfo.mobile,
          contentId: key,
          content: data[key],
          downFlag:
            itemConfig.componentType === "FileUpload" ||
            itemConfig.componentType === "ImgUpload"
              ? true
              : false,
        });
      }
    }
    try {
      const { data: formId, code } = await service.applyService.saveApplyItem({
        ...metaData,
        reportContents: forms,
      });
      if (code !== 200) {
        throw new Error();
      }
      const params = new FormData();
      params.append("businessId", formId);
      params.append("applicant", userInfo.id);
      params.append("processId", modalOption.metaData.processId);

      const { data: taskId, code: code2 } =
        await service.applyService.startExamine(params);
      if (code2 !== 200) {
        throw new Error();
      }

      const params2 = new FormData();
      params2.append("taskId", taskId);
      params2.append("user", userInfo.id);
      params2.append("approveComment", "已发起");
      /** 添加街道id */
      params2.append("streetId", mainBody?.streetCode);
      const { code: code3 } = await service.applyService.completeExamine(
        params2
      );
      if (code3 !== 200) {
        throw new Error();
      }

      message.success("提交成功");
      setModalOption({
        show: false,
        metaData: {},
      });
    } catch {
      message.error("提交失败");
    }
  });
  return (
    <BasicModal
      visible={visible}
      width={900}
      height={992}
      onClose={closeHandler}
      contentStyle={{ borderRadius: 10 }}
    >
      <div className={styles.container}>
        <div className={styles.header}>
          <img src={applyIcon} style={{ width: 46, height: 46 }} alt=""></img>
          <div className={styles.headerTitle}>
            申请·{modalOption.metaData.thingName}
          </div>
        </div>
        <div className={styles.modalBody}>
          <div className={styles.cardWrapper}>
            <Form
              form={form}
              colon={false}
              layout={"vertical"}
              onFinish={onFinish}
            >
              {formConfig.map((item: any) => {
                return (
                  <Form.Item
                    label={item.componentType === "Branch" ? "" : item.label}
                    name={item.key}
                    key={item.key}
                    rules={[
                      {
                        required: item.componentOption?.require,
                        message: `请填写${item?.label}`,
                      },
                      ...item.validationRules,
                    ]}
                  >
                    <RenderComponent
                      config={item.componentOption}
                      componentType={item.componentType}
                      metaData={item}
                    ></RenderComponent>
                  </Form.Item>
                );
              })}
            </Form>
          </div>
          <div style={{ float: "right", paddingTop: 34 }}>
            <Button
              type="primary"
              size="large"
              onClick={onSubmit}
              style={{ width: 150, height: 50 }}
            >
              提交
            </Button>
          </div>
        </div>
      </div>
    </BasicModal>
  );
};

export default SubmitApplication;
