import { notification } from "antd";
import { ResponseError, extend } from "umi-request";
const errorHandler = function (error: ResponseError<any>) {
  const codeMap = {
    424: "登陆失败或者登录已过期",
  } as Record<number, string>;
  if (error.response) {
    const pathname = location.pathname;
    if (codeMap[error.response.status]) {
      if (pathname.includes("management")) {
        localStorage.removeItem("admin_token");
      }
      if (pathname.includes("apply")) {
        localStorage.removeItem("user_token");
      }
    }
  }
  throw error;
};

const request = extend({
  /** 所有接口添加代理用的前缀 */
  prefix: "/apis",
  timeout: 20000,
  errorHandler,
});
const whiteList = [
  "/login/auth/oauth2/token",
  "/apis/hncy/matterInfo/listByUser",
];
/** 请求拦截器 */
request.interceptors.request.use(
  //@ts-ignore
  (url, options) => {
    let token = "";
    const pathname = location.pathname;
    if (pathname.includes("management")) {
      token = localStorage.getItem("admin_token") as string;
    }
    if (pathname.includes("apply")) {
      token = localStorage.getItem("user_token") as string;
    }
    console.log(url);

    if (!token && !whiteList.includes(url)) {
      return Promise.reject("未登录");
    }

    return {
      url,
      options: {
        ...options,
        headers: {
          Authorization: token ? `Bearer ${token}` : "",
          ...(pathname.includes("apply") ? { "CLIENT-TOC": "Y" } : {}),
          ...options.headers,
        },
      },
    };
  },
  { global: true }
);

// 提前对响应做异常处理
request.interceptors.response.use((response) => {
  const codeMaps = {
    // 1: "请先登录",
  } as Record<number, string>;
  const responseClone = response.clone();
  /** 消费全局code */
  responseClone.json().then((resValue) => {
    if (codeMaps[resValue.code]) {
      notification.open({
        type: "error",
        message: codeMaps[resValue.code],
        duration: 1.5,
      });
    }
  });

  return response;
});

export default request;
