import service from "@/service";
import { create } from "zustand";

interface UserState {
  userInfo?: any;
  adminInfo?: API.UserInfo;
  isSuperAdmin: boolean;
  updateAdminAuth(is: boolean): void;
  updateUserInfo: (userInfo: any) => void;
  updateAdminInfo: (adminInfo?: API.UserInfo) => void;
  /** 是否认证 */
  isAuth: boolean;
  /** 主体信息 */
  mainBodyInfo?: any[];
  queryMainBodyInfo(mobile?: string): void;
  /** 查询认证信息 */
  queryAuthenticationInfo(): void;
}

/** 用户信息的全局状态管理 */
const useUserStore = create<UserState>()((set) => ({
  userInfo: undefined,
  adminInfo: undefined,
  /** 是否是超级管理员 */
  isSuperAdmin: false,
  isAuth: false,
  mainBodyInfo: undefined,

  updateAdminAuth: (is: boolean) => {
    set({ isSuperAdmin: is });
  },

  /** 更新 */
  updateUserInfo: (userInfo: API.UserInfo) => {
    set({ userInfo });
  },

  updateAdminInfo: (adminInfo?: API.UserInfo) => {
    set({ adminInfo });
  },
  /** 查询认证信息 */
  queryAuthenticationInfo() {
    service.commonService.queryAuthenticationInfo().then((res) => {
      if (res.code === 200) {
        set({ isAuth: true });
      }
    });
  },

  /** 查询主体信息 */
  queryMainBodyInfo(mobile?: string) {
    if (mobile && mobile.length > 0) {
      service.commonService.getMainBodyInfo(mobile ?? "").then((res) => {
        if (res.code === 200) {
          set({ mainBodyInfo: res.data });
        }
      });
    }
  },
}));

export default useUserStore;
