import dev from "@/config/dev";
import CryptoJS from "crypto-js";
import jsPDF from "jspdf";
import * as htmlToImage from 'html-to-image'


// 密码加密
export function encryption(src: string, keyWord: string) {
    const key = CryptoJS.enc.Utf8.parse(keyWord);
    var encrypted = CryptoJS.AES.encrypt(src, key, {
        iv: key,
        mode: CryptoJS.mode.CFB,
        padding: CryptoJS.pad.NoPadding,
    });
    return encrypted.toString();
}

export function composeImgUrl(imgStr: string) {
    return `${dev.imgHost}${imgStr}`;
}

/**
 * 下载文件
 * @param {String} path - 下载地址/下载请求地址。
 * @param {String} name - 下载文件的名字/重命名（考虑到兼容性问题，最好加上后缀名）
 */
export function downloadFile(path: string, name: string) {
    const xhr = new XMLHttpRequest();
    xhr.open("get", path);
    xhr.responseType = "blob";
    xhr.send();
    xhr.onload = function () {
        if (this.status === 200 || this.status === 304) {
            // 如果是IE10及以上，不支持download属性，采用msSaveOrOpenBlob方法，但是IE10以下也不支持msSaveOrOpenBlob
            if ("msSaveOrOpenBlob" in navigator) {
                // navigator.msSaveOrOpenBlob(this.response, name);
                //@ts-ignore
                navigator.msSaveOrOpenBlob(this.response, name);
                return;
            }
            // const blob = new Blob([this.response], { type: xhr.getResponseHeader('Content-Type') });
            // const url = URL.createObjectURL(blob);
            const url = URL.createObjectURL(this.response);
            const a = document.createElement("a");
            a.style.display = "none";
            a.href = url;
            a.download = name;
            document.body.appendChild(a);
            a.click();
            document.body.removeChild(a);
            URL.revokeObjectURL(url);
        }
    };
}

export function downFlowFile(response: BlobPart, filename: string) {
    const blob = new Blob([response])
    const link = document.createElement('a')
    link.href = URL.createObjectURL(blob)
    link.download = filename
    document.body.appendChild(link)
    link.click()
    window.setTimeout(function () {
        // URL.revokeObjectURL(blob)
        URL.revokeObjectURL(link.href)
        document.body.removeChild(link)
    }, 0)
}



/**
 * 导出PDF
 * @param {导出后的文件名，无需后缀} filename
 * @param {要导出的dom节点} dom
 * @param {导出的文件水印} watermark
 */
export const exportPDF = (filename: string, dom: HTMLElement) => {
    htmlToImage.toPng(dom).then(function (dataUrl) {
        const imageData = new Image();
        imageData.src = dataUrl
        imageData.onload = () => {
            const { width, height } = imageData
            const pdf = new jsPDF(undefined, 'px');
            const pdfW = 595.28  //pdf 宽度
            const pdfH = 841.89  //pdf 高度
            const ratio = Math.min(pdfW / width, pdfH / height);
            pdf.addImage({ imageData, x: 0, y: 0, width: width * ratio * 0.75, height: height * ratio * 0.75 })
            pdf.save(`${filename}.pdf`)
        }
    })
}

